@@ -500,8 +500,14 @@ int MXMLSetVal(
   enum MDataFormatEnum Format) /* I */
 
   {
-  char  tmpLine[MMAX_LINE];
+  char *outbuf = NULL;
   char *ptr;
+  char  tmpLine[MMAX_LINE];
+
+  int Vlen;
+  int final_len = 0;
+  int buf_size = MMAX_LINE;
+  int i;
 
   if ((E == NULL) || (V == NULL))
     {
@@ -522,7 +528,104 @@ int MXMLSetVal(
 
     default:
 
+      /* temporarily use ptr as the input string */
       ptr = (char *)V;
+      Vlen = strlen(ptr);
+    
+      outbuf = (char *)malloc(buf_size*(sizeof(char)));
+      
+      if (outbuf == NULL)
+        {
+        fprintf(stderr,"Unable to allocate memory for XML output\n");
+        
+        return(FAILURE);
+        }
+
+      for (i = 0; i < Vlen; i++)
+        {
+        /* escape characters &"'<> */
+
+        /* check 7 because we could add 6 character and a NULL terminator */
+        if (final_len + 7 >= buf_size)
+          {
+          char *tmp;
+
+          buf_size += MMAX_LINE;
+          tmp = (char *)realloc(outbuf,buf_size);
+
+          if (tmp == NULL)
+            {
+            fprintf(stderr,"Unable to allocate memeory for XML output\n");
+            free(outbuf);
+            return(FAILURE);
+            }
+
+          outbuf = tmp;
+          }
+
+        /* escape characters &"'<> */
+        switch (ptr[i])
+          {
+          case '<':
+
+            outbuf[final_len++] = '&';
+            outbuf[final_len++] = 'l';
+            outbuf[final_len++] = 't';
+            outbuf[final_len++] = ';';
+
+            break;
+
+          case '>':
+
+            outbuf[final_len++] = '&';
+            outbuf[final_len++] = 'g';
+            outbuf[final_len++] = 't';
+            outbuf[final_len++] = ';';
+
+            break;
+            
+          case '&':
+
+            outbuf[final_len++] = '&';
+            outbuf[final_len++] = 'a';
+            outbuf[final_len++] = 'm';
+            outbuf[final_len++] = 'p';
+            outbuf[final_len++] = ';';
+
+            break;
+
+          case '"':
+  
+            outbuf[final_len++] = '&';
+            outbuf[final_len++] = 'q';
+            outbuf[final_len++] = 'u';
+            outbuf[final_len++] = 'o';
+            outbuf[final_len++] = 't';
+            outbuf[final_len++] = ';';
+
+            break;
+
+          case '\'':
+
+            outbuf[final_len++] = '&';
+            outbuf[final_len++] = 'a';
+            outbuf[final_len++] = 'p';
+            outbuf[final_len++] = 'o';
+            outbuf[final_len++] = 's';
+            outbuf[final_len++] = ';';
+
+            break;
+
+          default:
+            
+            outbuf[final_len++] = ptr[i];
+
+            break;
+          } /* END switch(ptr[i]) */
+
+        } /* END for (i < Vlen) */
+
+      outbuf[final_len] = '\0';
 
       break;
 
@@ -552,16 +655,16 @@ int MXMLSetVal(
       ptr = tmpLine;
 
       break;
-    }  /* END switch(Format) */
+    }  /* END switch (Format) */
 
-  E->Val = strdup(ptr);
-
-  /* strip '<' symbols  NOTE:  ignore '<' symbol in attrs */
-
-  /* NOTE:  must replace temp hack 14 w/ &lt; */
-
-  for (ptr = strchr(E->Val, '<');ptr != NULL;ptr = strchr(ptr, '<'))
-    * ptr = (char)14;
+  if (outbuf != NULL)
+    {
+    E->Val = outbuf;
+    }
+  else
+    {
+    E->Val = strdup(ptr);
+    }
 
   return(SUCCESS);
   }  /* END MXMLSetVal() */
