@@ -81,7 +81,7 @@
 */
 
 /*
- * @(#) $Id: cmds.h 3102 2009-08-26 20:29:23Z ataufer $
+ * @(#) $Id: cmds.h 3609 2010-05-17 21:08:44Z dbeer $
  */
 
 /*
@@ -122,7 +122,7 @@ int locate_job A_((char *, char *, char *));
 int parse_destination_id A_((char *, char **, char **));
 int parse_equal_string A_((char *, char **, char **));
 int parse_jobid A_((char *, char **, char **, char **));
-int prepare_path A_((char *, char*));
+int prepare_path A_((char *, char *,char *));
 void prt_error A_((char *, char *, int));
 void set_attr A_((struct attrl **, char *, char *));
 int set_resources A_((struct attrl **, char *, int));
