@@ -78,14 +78,15 @@
 */
 
 /*
- * This is a list of public queue attributes
+ *  This is a list of public queue attributes
  *
- * FORMAT:
+ *  FORMAT:
  *  attr1,
  *   attr2, <--- important the last has a comma after it
  *
  *  This file will be used for the initialization of an array
  *
+ *  @see que_public_attrs[] in cmds/qmgr.c
  */
 
 ATTR_aclgren,
@@ -94,8 +95,8 @@ ATTR_aclhten,
 ATTR_aclhost,
 ATTR_acluren,
 ATTR_acluser,
-ATTR_chkptdir,
-ATTR_chkptmin,
+ATTR_checkpoint_dir,
+ATTR_checkpoint_min,
 ATTR_enable,
 ATTR_fromroute,
 ATTR_killdelay,
@@ -128,3 +129,4 @@ ATTR_keepcompleted,
 ATTR_disallowedtypes,
 ATTR_hostlist,
 ATTR_rerunnable,
+ATTR_is_transit,
