@@ -147,6 +147,8 @@ ATTR_extraresc,
 ATTR_schedversion,
 ATTR_acctkeepdays,
 ATTR_lockfile,
+ATTR_LockfileUpdateTime,
+ATTR_LockfileCheckTime,
 ATTR_credentiallifetime,
 ATTR_jobmustreport,
 ATTR_checkpoint_dir,
