@@ -169,9 +169,10 @@ enum srv_atr
   SRV_ATR_display_job_server_suffix,
   SRV_ATR_job_suffix_alias,
   SRV_ATR_MailSubjectFmt,
-  SRV_ATR_MailBodyFmt,
+  SRV_ATR_MailBodyFmt,           /* 70 */
   SRV_ATR_NPDefault,
   SRV_ATR_JobStartTimeout,
+  SRV_ATR_JobForceCancelTime,
 #include "site_svr_attr_enum.h"
   /* This must be last */
   SRV_ATR_LAST
