@@ -78,7 +78,7 @@
 */
 
 /*
- * @(#) $Id: server_limits.h 2864 2009-03-30 23:54:12Z ataufer $
+ * @(#) $Id: server_limits.h 3138 2009-09-29 21:43:58Z knielson $
  */
 
 /*
@@ -114,6 +114,8 @@
                                      if log_file_max_size is set */
 #define PBS_ACCT_CHECK_RATE   60*60  /* check accounting files every hour
 																		 if accounting_keep_days is set */
+#define PBS_LOCKFILE_UPDATE_TIME 3   /* how often TORQUE updates HA lock file */
+#define PBS_LOCKFILE_CHECK_TIME  9   /* how often secondary TORQUE checks HA lock file */
 
 /* Server Database information - path names */
 
@@ -122,6 +124,7 @@
 #define PBS_ARRAYDIR  "arrays"
 #define PBS_JOBDIR  "jobs"
 #define PBS_SPOOLDIR  "spool"
+#define PBS_CHKPTDIR  "checkpoint"
 #define PBS_QUEDIR  "queues"
 #define PBS_LOGFILES  "server_logs"
 #define PBS_ACTFILES  "accounting"
@@ -132,9 +135,17 @@
 #define NODE_STATUS  "node_status"
 #define NODE_NOTE  "node_note"
 
-
 #ifndef PBS_NET_MAX_CONNECTIONS
-#define PBS_NET_MAX_CONNECTIONS 1024  /* increased from 256 */
+/* 
+ * PBS_NET_MAX_CONNECTIONS is used to limit both socket descriptors and socket
+ * handles. Tests show that often socket handles are used up much faster than
+ * socket descriptors (is there a leak of socket handles???). In the future, we
+ * should probably break out handle size and socket descriptor size and the
+ * socket descriptor size should equal getdtablesize(). For now, however,
+ * PBS_NET_MAX_CONNECTIONS should be larger than ulimit -n due to more socket
+ * handles being handed out than sockets are available.
+ */
+#define PBS_NET_MAX_CONNECTIONS 10240  /* increased from 256--should be larger than ulimit -n */
 #endif /* PBS_NET_MAX_CONNECTIONS */
 
 #define PBS_LOCAL_CONNECTION PBS_NET_MAX_CONNECTIONS
