@@ -271,16 +271,17 @@ int attr_atomic_set(
  * values from an svrattrl
 */
 
-int attr_atomic_node_set(plist, old, new, pdef, limit, unkn, privil, badattr)
-
-struct svrattrl *plist;  /*list of attribute modif structs*/
-attribute *old;  /*unused*/
-attribute *new;  /*new attribute array begins here*/
-attribute_def *pdef;  /*begin array  definition structs*/
-int   limit;  /*number elts in definition array*/
-int   unkn;  /*<0 unknown attrib not permitted*/
-int   privil; /*requester's access privileges  */
-int  *badattr; /*return list position wher bad  */
+int
+attr_atomic_node_set(
+  struct svrattrl *plist,  /*list of attribute modif structs*/
+  attribute *old,  /*unused*/
+  attribute *new,  /*new attribute array begins here*/
+  attribute_def *pdef,  /*begin array  definition structs*/
+  int limit,  /*number elts in definition array*/
+  int unkn,  /*<0 unknown attrib not permitted*/
+  int privil, /*requester's access privileges  */
+  int *badattr /*return list position wher bad  */
+)
 
   {
   int     acc;
@@ -399,10 +400,8 @@ int  *badattr; /*return list position wher bad  */
  * the array itself is freed.
  */
 
-void attr_atomic_kill(temp, pdef, limit)
-attribute *temp;
-attribute_def *pdef;
-int   limit;
+void
+attr_atomic_kill(attribute *temp, attribute_def *pdef, int limit)
   {
   int i;
 
