@@ -123,12 +123,13 @@
  *  *patr elements set
  */
 
-int decode_ll(patr, name, rescn, val)
-
-struct attribute *patr;
-char *name;  /* attribute name */
-char *rescn;  /* resource name, unused here */
-char *val;  /* attribute value */
+int
+decode_ll(
+  struct attribute *patr,
+  char *name,  /* attribute name */
+  char *rescn,  /* resource name, unused here */
+  char *val  /* attribute value */
+)
   {
   char *pc;
 
@@ -162,12 +163,14 @@ char *val;  /* attribute value */
 /*ARGSUSED*/
 
 
-int encode_ll(attr, phead, atname, rsname, mode)
-attribute *attr;   /* ptr to attribute */
-tlist_head *phead;   /* head of attrlist list */
-char  *atname;  /* attribute name */
-char  *rsname;  /* resource name or null */
-int  mode;   /* encode mode, unused here */
+int
+encode_ll(
+  attribute *attr,   /* ptr to attribute */
+  tlist_head *phead,   /* head of attrlist list */
+  char *atname,  /* attribute name */
+  char *rsname,  /* resource name or null */
+  int mode   /* encode mode, unused here */
+)
   {
   size_t   ct;
   const char *cvn;
