@@ -396,17 +396,20 @@ svrattrl *attrlist_create(
  * structures
  */
 
-void free_attrlist(pattrlisthead)
-tlist_head *pattrlisthead;
+void
+free_attrlist(tlist_head *pattrlisthead)
   {
   svrattrl *pal;
   svrattrl *nxpal;
 
-  if (pattrlisthead == NULL || pattrlisthead->ll_next == NULL)
+  if (pattrlisthead == NULL)
     {
-    return;
+      return;
+    }
+  if (pattrlisthead->ll_next == NULL)
+    {
+      return;
     }
-
   pal = (svrattrl *)GET_NEXT(*pattrlisthead);
 
   while (pal != (svrattrl *)0)
@@ -676,8 +679,10 @@ count_substrings(
  * within a svrattrl list.
  */
 
-void attrl_fixlink(phead)
-tlist_head *phead; /* pointer to head of svrattrl list */
+void
+attrl_fixlink(
+  tlist_head *phead /* pointer to head of svrattrl list */
+)
   {
   svrattrl *pal;
   svrattrl *pnxt;
