@@ -237,7 +237,10 @@ int prepare_path(
 
   strcat(path_out, ":");
 
-  if ((path_name[0] != '/') && (strncmp(path_name,"$HOME",strlen("$HOME")) != 0) && (host_given == NULL))
+  if ((path_name[0] != '/') && 
+      (strncmp(path_name,"$HOME",strlen("$HOME")) != 0) && 
+      (strncmp(path_name,"${HOME}",strlen("${HOME}")) != 0) &&
+      (host_given == NULL))
     {
     c = getenv("PWD");  /* PWD carries a name that will cause */
 
