@@ -99,7 +99,6 @@
 #include "batch_request.h"
 
 extern int decode_DIS_attrl(int, struct attrl **);
-extern int tcp_decode_DIS_attrl(int, struct attrl **);
 
 
 int decode_DIS_replyCmd(
@@ -371,273 +370,6 @@ int decode_DIS_replyCmd(
   }  /* END decode_DIS_replyCmd() */
 
 
-int tcp_decode_DIS_replyCmd(
-
-  int                 sock,
-  struct batch_reply *reply)
-
-  {
-  int          ct;
-  int          i;
-
-  struct brp_select    *psel;
-
-  struct brp_select   **pselx;
-
-  struct brp_cmdstat   *pstcmd;
-
-  struct brp_cmdstat  **pstcx;
-  int                   rc = 0;
-
-  /* first decode "header" consisting of protocol type and version */
-
-  i = tcp_disrui(sock, &rc);
-
-  if (rc != 0)
-    {
-    return(rc);
-    }
-
-  if (i != PBS_BATCH_PROT_TYPE)
-    {
-    return(DIS_PROTO);
-    }
-
-  i = tcp_disrui(sock, &rc);
-
-  if (rc != 0)
-    {
-    return(rc);
-    }
-
-  if (i != PBS_BATCH_PROT_VER)
-    {
-    return(DIS_PROTO);
-    }
-
-  /* next decode code, auxcode and choice (union type identifier) */
-
-  reply->brp_code = tcp_disrsi(sock, &rc);
-
-  if (rc != 0)
-    {
-    return(rc);
-    }
-
-  reply->brp_auxcode = tcp_disrsi(sock, &rc);
-
-  if (rc != 0)
-    {
-    return(rc);
-    }
-
-  reply->brp_choice = tcp_disrui(sock, &rc);
-
-  if (rc != 0)
-    {
-    return(rc);
-    }
-
-  switch (reply->brp_choice)
-    {
-
-    case BATCH_REPLY_CHOICE_NULL:
-
-      break;  /* no more to do */
-
-    case BATCH_REPLY_CHOICE_Queue:
-
-    case BATCH_REPLY_CHOICE_RdytoCom:
-
-    case BATCH_REPLY_CHOICE_Commit:
-
-      if ((rc = tcp_disrfst(sock, PBS_MAXSVRJOBID + 1, reply->brp_un.brp_jid)))
-        {
-        return(rc);
-        }
-
-      break;
-
-    case BATCH_REPLY_CHOICE_Select:
-
-      /* have to get count of number of strings first */
-
-      reply->brp_un.brp_select = NULL;
-
-      pselx = &reply->brp_un.brp_select;
-
-      ct = tcp_disrui(sock, &rc);
-
-      if (rc)
-        {
-        return(rc);
-        }
-
-      while (ct--)
-        {
-        psel = (struct brp_select *)malloc(sizeof(struct brp_select));
-
-        if (psel == NULL)
-          {
-          return(DIS_NOMALLOC);
-          }
-
-        psel->brp_next = NULL;
-
-        psel->brp_jobid[0] = '\0';
-
-        rc = tcp_disrfst(sock, PBS_MAXSVRJOBID + 1, psel->brp_jobid);
-
-        if (rc)
-          {
-          free(psel);
-
-          return(rc);
-          }
-
-        *pselx = psel;
-
-        pselx  = &psel->brp_next;
-        }
-
-      break;
-
-    case BATCH_REPLY_CHOICE_Status:
-
-      /* have to get count of number of status objects first */
-
-      reply->brp_un.brp_statc = NULL;
-
-      pstcx = &reply->brp_un.brp_statc;
-
-      ct = tcp_disrui(sock, &rc);
-
-      if (rc)
-        {
-        return(rc);
-        }
-
-      while (ct--)
-        {
-        pstcmd = (struct brp_cmdstat *)malloc(sizeof(struct brp_cmdstat));
-
-        if (pstcmd == NULL)
-          {
-          return(DIS_NOMALLOC);
-          }
-
-        pstcmd->brp_stlink = NULL;
-
-        pstcmd->brp_objname[0] = '\0';
-
-        pstcmd->brp_attrl = NULL;
-
-        pstcmd->brp_objtype = tcp_disrui(sock, &rc);
-
-        if (rc == 0)
-          {
-          rc = tcp_disrfst(sock, PBS_MAXSVRJOBID + 1, pstcmd->brp_objname);
-          }
-
-        if (rc)
-          {
-          free(pstcmd);
-
-          return(rc);
-          }
-
-        rc = tcp_decode_DIS_attrl(sock, &pstcmd->brp_attrl);
-
-        if (rc)
-          {
-          free(pstcmd);
-
-          return(rc);
-          }
-
-        *pstcx = pstcmd;
-
-        pstcx  = &pstcmd->brp_stlink;
-        }
-
-      break;
-
-    case BATCH_REPLY_CHOICE_Text:
-
-      /* text reply */
-
-      reply->brp_un.brp_txt.brp_str = tcp_disrcs(
-                                        sock,
-                                        &reply->brp_un.brp_txt.brp_txtlen,
-                                        &rc);
-
-      break;
-
-    case BATCH_REPLY_CHOICE_Locate:
-
-      /* Locate Job Reply */
-
-      rc = tcp_disrfst(sock, PBS_MAXDEST + 1, reply->brp_un.brp_locate);
-
-      break;
-
-    case BATCH_REPLY_CHOICE_RescQuery:
-
-      /* Resource Query Reply */
-
-      reply->brp_un.brp_rescq.brq_avail = NULL;
-      reply->brp_un.brp_rescq.brq_alloc = NULL;
-      reply->brp_un.brp_rescq.brq_resvd = NULL;
-      reply->brp_un.brp_rescq.brq_down  = NULL;
-
-      ct = tcp_disrui(sock, &rc);
-
-      if (rc)
-        break;
-
-      reply->brp_un.brp_rescq.brq_number = ct;
-
-      reply->brp_un.brp_rescq.brq_avail  = (int *)malloc(ct * sizeof(int));
-
-      reply->brp_un.brp_rescq.brq_alloc  = (int *)malloc(ct * sizeof(int));
-
-      reply->brp_un.brp_rescq.brq_resvd  = (int *)malloc(ct * sizeof(int));
-
-      reply->brp_un.brp_rescq.brq_down   = (int *)malloc(ct * sizeof(int));
-
-      if ((reply->brp_un.brp_rescq.brq_avail == NULL) ||
-          (reply->brp_un.brp_rescq.brq_alloc == NULL) ||
-          (reply->brp_un.brp_rescq.brq_resvd == NULL) ||
-          (reply->brp_un.brp_rescq.brq_down == NULL)) 
-        {
-        return(DIS_NOMALLOC);
-        }
-
-      for (i = 0;(i < ct) && (rc == 0);++i)
-        *(reply->brp_un.brp_rescq.brq_avail + i) = tcp_disrui(sock, &rc);
-
-      for (i = 0;(i < ct) && (rc == 0);++i)
-        *(reply->brp_un.brp_rescq.brq_alloc + i) = tcp_disrui(sock, &rc);
-
-      for (i = 0;(i < ct) && (rc == 0);++i)
-        *(reply->brp_un.brp_rescq.brq_resvd + i) = tcp_disrui(sock, &rc);
-
-      for (i = 0;(i < ct) && (rc == 0);++i)
-        *(reply->brp_un.brp_rescq.brq_down + i)  = tcp_disrui(sock, &rc);
-
-      break;
-
-    default:
-
-      return(-1);
-
-      /*NOTREACHED*/
-
-      break;
-    }  /* END switch (reply->brp_choice) */
-
-  return(rc);
-  }  /* END tcp_decode_DIS_replyCmd() */
 
 /* END dec_rpyc.c */
 
