@@ -99,31 +99,6 @@
 #include "batch_request.h"
 #include "dis.h"
 
-int tcp_encode_DIS_JobObit(
-
-  int                   sock,  /* I */
-  struct batch_request *preq)  /* I */
-
-  {
-  int              rc;
-
-  struct svrattrl *psvrl;
-
-  psvrl = (struct svrattrl *)GET_NEXT(preq->rq_ind.rq_jobobit.rq_attr);
-
-  if ((rc = tcp_diswst(sock, preq->rq_ind.rq_jobobit.rq_jid) != 0) ||
-      (rc = tcp_diswsi(sock, preq->rq_ind.rq_jobobit.rq_status) != 0) ||
-      (rc = tcp_encode_DIS_svrattrl(sock, psvrl) != 0))
-    {
-    /* FAILURE */
-
-    return(rc);
-    }
-
-  return(0);
-  }  /* END tcp_encode_DIS_JobObit() */
-
-
 int encode_DIS_JobObit(
 
   int                   sock,  /* I */
