@@ -140,7 +140,10 @@ int pbs_alterjob_asyncflag(
 
     ap->resource = attrib->resource;
     ap->value = attrib->value;
-    ap->op = SET;
+
+    /* attributes now must have an op specified. Inside TORQUE this defaults
+     * to SET, ensuring the same behavior as before */
+    ap->op = attrib->op;
     ap->next = (struct attropl *)NULL;
     attrib = attrib->next;
     }  /* END while (attrib != NULL) */
