@@ -137,6 +137,10 @@ static const char *pbs_destn_file = PBS_DEFAULT_FILE;
 
 char *pbs_server = NULL;
 
+void empty_alarm_handler(int signo)
+  {
+  }
+
 
 /**
  * Attempts to get a list of server names.  Trys first
@@ -877,20 +881,22 @@ int pbs_disconnect(
 
     /* set alarm to break out of potentially infinite read */
 
-    act.sa_handler = SIG_IGN;
+    /* act.sa_handler = SIG_IGN; */
+    act.sa_handler = empty_alarm_handler;  /* need SOME handler or blocking read never gets interrupted */
+
     sigemptyset(&act.sa_mask);
     act.sa_flags = 0;
     sigaction(SIGALRM, &act, &oldact);
 
     atime = alarm(pbs_tcp_timeout);
 
-    /* NOTE:  alarm will break out of blocking read even with sigaction ignored */
-
     while (1)
       {
       /* wait for server to close connection */
 
-      /* NOTE:  if read of 'sock' is blocking, request below may hang forever */
+      /* NOTE:  if read of 'sock' is blocking, request below may hang forever 
+       * hence the signal handler empty_alarm_handler above 
+       */
 
       if (read(sock, &x, sizeof(x)) < 1)
         break;
