@@ -87,11 +87,8 @@
 #include <stdio.h>
 #include "libpbs.h"
 
-int pbs_rlsjob(c, jobid, holdtype, extend)
-int c;
-char *jobid;
-char *holdtype;
-char *extend;
+int
+pbs_rlsjob(int c, char *jobid, char *holdtype, char *extend)
   {
 
   struct attropl aopl;
