@@ -167,12 +167,11 @@ static char *mk_log_name(
   {
 
   struct tm *ptm;
-
   struct tm  tmpPtm;
   time_t time_now;
 
   time_now = time((time_t *)0);
-  ptm = localtime_r(&time_now, &tmpPtm);
+  ptm = localtime_r(&time_now,&tmpPtm);
 
   if (log_suffix[0] != '\0')
     {
@@ -533,7 +532,6 @@ void log_record(
   time_t now;
 
   struct tm *ptm;
-
   struct tm  tmpPtm;
   int    rc = 0;
   FILE  *savlog;
@@ -547,7 +545,7 @@ void log_record(
 
   now = time((time_t *)0); /* get time for message */
 
-  ptm = localtime_r(&now, &tmpPtm);
+  ptm = localtime_r(&now,&tmpPtm);
 
   /* Do we need to switch the log? */
 
@@ -581,20 +579,21 @@ void log_record(
 
     while (tryagain)
       {
-      rc = fprintf(logfile,"%02d/%02d/%04d %02d:%02d:%02d;%04x;%10.10s;%s;%s;%s%.*s\n",
-             ptm->tm_mon + 1,
-             ptm->tm_mday,
-             ptm->tm_year + 1900,
-             ptm->tm_hour,
-             ptm->tm_min,
-             ptm->tm_sec,
-             (eventtype & ~PBSEVENT_FORCE),
-             msg_daemonname,
-             class_names[objclass],
-             objname,
-             (text == start ? "" : "[continued]"),
-             (int)nchars, 
-             start);
+      rc = fprintf(logfile,
+              "%02d/%02d/%04d %02d:%02d:%02d;%04x;%10.10s;%s;%s;%s%.*s\n",
+              ptm->tm_mon + 1,
+              ptm->tm_mday,
+              ptm->tm_year + 1900,
+              ptm->tm_hour,
+              ptm->tm_min,
+              ptm->tm_sec,
+              (eventtype & ~PBSEVENT_FORCE),
+              msg_daemonname,
+              class_names[objclass],
+              objname,
+              (text == start ? "" : "[continued]"),
+              (int)nchars,
+              start);
 
       if ((rc < 0) &&
           (errno == EPIPE) &&
@@ -604,7 +603,7 @@ void log_record(
          * reopen log and leave the previous file descriptor alone--do not close it */
 
         log_opened = 0;
-        log_open(NULL,log_directory);
+        log_open(NULL, log_directory);
         tryagain--;
         }
       else
@@ -629,8 +628,8 @@ void log_record(
     rc = errno;
     clearerr(logfile);
     savlog = logfile;
-    logfile = fopen("/dev/console","w");
-    log_err(rc,"log_record","PBS cannot write to its log");
+    logfile = fopen("/dev/console", "w");
+    log_err(rc, "log_record", "PBS cannot write to its log");
     fclose(logfile);
     logfile = savlog;
     }
@@ -815,9 +814,9 @@ void log_roll(
 
   file_buf_len = sizeof(char) * (strlen(logpath) + suffix_size + 1);
 
-  source = (char *)malloc(file_buf_len);
+  source = (char*)malloc(file_buf_len);
 
-  dest   = (char *)malloc(file_buf_len);
+  dest   = (char*)malloc(file_buf_len);
 
   if ((source == NULL) || (dest == NULL))
     {
@@ -829,7 +828,7 @@ void log_roll(
   /* call unlink to delete logname.max_depth - it doesn't matter if it
      doesn't exist, so we'll ignore ENOENT */
 
-  sprintf(dest,"%s.%d",
+  sprintf(dest, "%s.%d",
     logpath,
     max_depth);
 
@@ -845,22 +844,22 @@ void log_roll(
     {
     if (i == 0)
       {
-      strcpy(source,logpath);
+      strcpy(source, logpath);
       }
     else
       {
-      sprintf(source,"%s.%d",
+      sprintf(source, "%s.%d",
         logpath,
         i);
       }
 
-    sprintf(dest,"%s.%d",
+    sprintf(dest, "%s.%d",
       logpath,
       i + 1);
 
     /* rename file if it exists */
 
-    if ((rename(source,dest) != 0) && (errno != ENOENT))
+    if ((rename(source, dest) != 0) && (errno != ENOENT))
       {
       err = errno;
       goto done_roll;
@@ -871,11 +870,11 @@ done_roll:
 
   if (as)
     {
-    log_open(NULL,log_directory);
+    log_open(NULL, log_directory);
     }
   else
     {
-    log_open(logpath,log_directory);
+    log_open(logpath, log_directory);
     }
 
   if (source != NULL)
@@ -886,7 +885,7 @@ done_roll:
 
   if (err != 0)
     {
-    log_err(err,"log_roll","error while rollng logs");
+    log_err(err, "log_roll", "error while rollng logs");
     }
   else
     {
