@@ -85,12 +85,10 @@
 #include "attribute.h"
 #include "server_limits.h"
 #include "queue.h"
-#include "job.h"
+#include "pbs_job.h"
 
-int site_alt_router(jobp, qp, retry_time)
-job  *jobp;
-pbs_queue *qp;
-long   retry_time;
+int
+site_alt_router(job *jobp, pbs_queue *qp, long retry_time)
   {
   return (default_router(jobp, qp, retry_time));
   }
