@@ -118,7 +118,7 @@
 #include "server_limits.h"
 #include "attribute.h"
 #include "resource.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "log.h"
 #include "resmon.h"
 #include "../rm_dep.h"
@@ -173,7 +173,9 @@ extern  double  cputfactor;
 extern double  wallfactor;
 extern  long     system_ncpus;
 extern  int      ignwalltime;
+extern  int      igncput;
 extern  int      ignvmem;
+extern  int      ignmem;
 
 /*
 ** local functions
@@ -226,7 +228,6 @@ static int  nncpus;
 static uint   realmem;
 static long  page_size;
 
-extern struct pbs_err_to_txt pbs_err_to_txt[];
 extern time_t   time_now;
 
 extern char extra_parm[];
@@ -259,8 +260,8 @@ get_swtbl_num(void)
     if (fgets(buf, SWNODEBUFSZ - 1, pp) == NULL)
       break;
 
-    sscanf(buf,"%s %d", 
-      name, 
+    sscanf(buf, "%s %d",
+      name,
       &swtbl_num[i].sw_num);
 
     if (swtbl_num[i].sw_name != NULL)
@@ -271,7 +272,7 @@ get_swtbl_num(void)
 
   if (pclose(pp) != 0)
     {
-    return(-1);
+    return (-1);
     }
 
   ibm_sp2_num_nodes = i;
@@ -308,7 +309,7 @@ void dep_initialize(void)
 
   if (swap_dev == NULL)
     {
-    if ((swap_dev = (char **)calloc(10,sizeof(char *)))==NULL)
+    if ((swap_dev = (char **)calloc(10,sizeof(char *))) == NULL)
       {
       /* FAILURE - cannot alloc memory */
 
@@ -320,15 +321,15 @@ void dep_initialize(void)
 
   page_size = sysconf(_SC_PAGESIZE);
 
-  if ((fil = fopen(swapfil,"r")) == NULL)
+  if ((fil = fopen(swapfil, "r")) == NULL)
     {
-    log_err(errno,id,swapfil);
+    log_err(errno, id, swapfil);
     }
   else
     {
     char **tmpSwapDev;
 
-    for (i = 0;fgets(line,sizeof(line),fil);)
+    for (i = 0; fgets(line, sizeof(line), fil);)
       {
       if (line[0] == '*')
         continue;
@@ -346,13 +347,13 @@ void dep_initialize(void)
       tmpSwapDev = (char **)realloc(swap_dev,(i + 2) * sizeof(char *));
 
       if (tmpSwapDev == NULL)
-	{
+      	{
         /* FAILURE - cannot alloc memory */
 
         log_err(errno,"dep_initialize","realloc failure");
 
         return;
-	}
+      	}
 
       swap_dev = tmpSwapDev;
 
@@ -393,10 +394,10 @@ void dep_initialize(void)
 
   if (fcntl(kd, F_SETFD, i) == -1)
     {
-    log_err(errno,id,"F_SETFD");
+    log_err(errno, id, "F_SETFD");
     }
 
-  if ((proc_tbl = malloc(ASIZE * sizeof(struct procsinfo)))==NULL)
+  if ((proc_tbl = malloc(ASIZE * sizeof(struct procsinfo))) == NULL)
     {
     /* FAILURE - cannot alloc memory */
 
@@ -549,9 +550,8 @@ void dep_main_loop_cycle(void)
  *  sizeof(word) = sizeof(int)
  */
 
-static int getsize(pres, ret)
-resource  *pres;
-unsigned long *ret;
+static int
+getsize(resource *pres, unsigned long *ret)
   {
   unsigned long value;
 
@@ -586,9 +586,8 @@ unsigned long *ret;
  * decoded value of time in seconds in the unsigned long integer.
  */
 
-static int gettime(pres, ret)
-resource  *pres;
-unsigned long *ret;
+static int
+gettime(resource *pres, unsigned long *ret)
   {
 
   if (pres->rs_value.at_type != ATR_TYPE_LONG)
@@ -630,8 +629,8 @@ pid_t  sesid;
  * Accepts a session id.  Returns the sum of all cpu time consumed for all
  * tasks executed by the job, in seconds, adjusted by cputfactor.
  */
-static unsigned long cput_sum(pjob)
-job  *pjob;
+static unsigned long
+cput_sum(job *pjob)
   {
   char   *id = "cput_ses";
   int   i;
@@ -686,8 +685,8 @@ job  *pjob;
  * Accepts a session ID.  Returns the total number of bytes of address
  * space consumed by all current tasks within the job.
  */
-static unsigned long mem_sum(pjob)
-job   *pjob;
+static unsigned long
+mem_sum(job *pjob)
   {
   char  *id = "mem_ses";
   int  i;
@@ -717,8 +716,8 @@ job   *pjob;
 /*
  * Internal session mem (workingset) size function.
  */
-static unsigned long resi_sum(pjob)
-job   *pjob;
+static unsigned long
+resi_sum(job *pjob)
   {
   char  *id = "resi_ses";
   int  i;
@@ -753,9 +752,8 @@ job   *pjob;
 /*
  * Return TRUE if any process in the job is over limit for memory usage.
  */
-static int overmem_proc(pjob, limit)
-job   *pjob;
-unsigned long limit;
+static int
+overmem_proc(job *pjob, unsigned long limit)
   {
   int  i;
 
@@ -785,28 +783,14 @@ extern char *msg_momsetlim;
 int
 error(char *string, int value)
   {
-  int  i = 0;
   char  *message;
 
   assert(string != NULL);
   assert(*string != '\0');
-  assert(value > PBSE_);   /* minimum PBS error number */
-  assert(value <= PBSE_NOSYNCMSTR); /* maximum PBS error number */
-  assert(pbs_err_to_txt[i].err_no != 0);
 
-  do
-    {
-    if (pbs_err_to_txt[i].err_no == value)
-      break;
-    }
-  while (pbs_err_to_txt[++i].err_no != 0);
-
-  assert(pbs_err_to_txt[i].err_txt != NULL);
-
-  message = *pbs_err_to_txt[i].err_txt;
+  message = pbse_to_txt(value);
 
   assert(message != NULL);
-
   assert(*message != '\0');
 
   (void)fprintf(stderr, msg_momsetlim, string, message);
@@ -837,9 +821,11 @@ error(char *string, int value)
  * existing limits.  Cannot alter those set by setrlimit (kernel)
  * because we are the wrong process.
  */
-int mom_set_limits(pjob, set_mode)
-job   *pjob;
-int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
+int
+mom_set_limits(
+  job *pjob,
+  int set_mode /* SET_LIMIT_SET or SET_LIMIT_ALTER */
+)
   {
   char  *id = "mom_set_limits";
   char  *pname;
@@ -872,25 +858,31 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
 
     if (strcmp(pname, "cput") == 0)
       {
-      /* cpu time - check, if less than pcput use it */
-      retval = gettime(pres, &value);
+      if (igncput == FALSE)
+        {
+        /* cpu time - check, if less than pcput use it */
+        retval = gettime(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
+        }
       }
     else if (strcmp(pname, "pcput") == 0)
       {
-      /* process cpu time - set */
-      retval = gettime(pres, &value);
+      if (igncput == FALSE)
+        {
+        /* process cpu time - set */
+        retval = gettime(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
 
-      reslim.rlim_cur = reslim.rlim_max =
-                          (unsigned long)((double)value / cputfactor);
+        reslim.rlim_cur = reslim.rlim_max =
+          (unsigned long)((double)value / cputfactor);
 
-      if (setrlimit(RLIMIT_CPU, &reslim) < 0)
-        return (error("RLIMIT_CPU", PBSE_SYSTEM));
+        if (setrlimit(RLIMIT_CPU, &reslim) < 0)
+          return (error("RLIMIT_CPU", PBSE_SYSTEM));
+        }
       }
     else if (strcmp(pname, "file") == 0)   /* set */
       {
@@ -912,43 +904,52 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
       }
     else if (strcmp(pname, "vmem") == 0)   /* check */
       {
-      retval = getsize(pres, &value);
-
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
-
-      if ((mem_limit == 0) || (value < mem_limit))
-        mem_limit = value;
-      }
-    else if (strcmp(pname, "pvmem") == 0)   /* set */
-      {
-      if (set_mode == SET_LIMIT_SET)
+      if (ignvmem == FALSE)
         {
         retval = getsize(pres, &value);
 
         if (retval != PBSE_NONE)
           return (error(pname, retval));
 
-        if (value > INT_MAX)
-          return (error(pname, PBSE_BADATVAL));
-
         if ((mem_limit == 0) || (value < mem_limit))
           mem_limit = value;
         }
       }
+    else if (strcmp(pname, "pvmem") == 0)   /* set */
+      {
+      if (ignvmem == FALSE)
+        {
+        if (set_mode == SET_LIMIT_SET)
+          {
+          retval = getsize(pres, &value);
+
+          if (retval != PBSE_NONE)
+            return (error(pname, retval));
+
+          if (value > INT_MAX)
+            return (error(pname, PBSE_BADATVAL));
+
+          if ((mem_limit == 0) || (value < mem_limit))
+            mem_limit = value;
+          }
+        }
+      }
     else if (strcmp(pname, "pmem") == 0)   /* set */
       {
-      if (set_mode == SET_LIMIT_SET)
+      if (ignmem == FALSE)
         {
-        retval = getsize(pres, &value);
+        if (set_mode == SET_LIMIT_SET)
+          {
+          retval = getsize(pres, &value);
 
-        if (retval != PBSE_NONE)
-          return (error(pname, retval));
+          if (retval != PBSE_NONE)
+            return (error(pname, retval));
 
-        reslim.rlim_cur = reslim.rlim_max = value;
+          reslim.rlim_cur = reslim.rlim_max = value;
 
-        if (setrlimit(RLIMIT_RSS, &reslim) < 0)
-          return (error("RLIMIT_RSS", PBSE_SYSTEM));
+          if (setrlimit(RLIMIT_RSS, &reslim) < 0)
+            return (error("RLIMIT_RSS", PBSE_SYSTEM));
+          }
         }
       }
     else if (strcmp(pname, "walltime") == 0)   /* Check */
@@ -1002,8 +1003,8 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
  * polling is done using the mom_over_limit machine-dependent function.
  */
 
-int mom_do_poll(pjob)
-job   *pjob;
+int
+mom_do_poll(job *pjob)
   {
   char  *id = "mom_do_poll";
   char  *pname;
@@ -1178,6 +1179,7 @@ static unsigned long nodes_ses(
   char  *nodes;
   char  *badnodes = "";
 
+
   DBPRT(("%s: entered\n", id))
 
   /*
@@ -1191,6 +1193,7 @@ static unsigned long nodes_ses(
 
   for (i = 0; i < nproc; i++)
     {
+
     register struct procsinfo *pp = &proc_tbl[i];
 
     if (pp->pi_state == SNONE)
@@ -1209,6 +1212,7 @@ static unsigned long nodes_ses(
 
     for (j = 0; j < njob; j++)
       {
+
       struct JM_JOB_STATUS *jp = &job_tbl[j];
       int len, hit;
       char *end;
@@ -1228,7 +1232,7 @@ static unsigned long nodes_ses(
 
       hit = 0;
 
-      for (k = 0;k < jp->jm_num_nodes;k++)
+      for (k = 0; k < jp->jm_num_nodes; k++)
         {
         struct JM_NODE_IN_JOB *np = &jp->jm_node_in_job[k];
 
@@ -1256,7 +1260,7 @@ static unsigned long nodes_ses(
         ** in the "badnodes" list
         */
 
-        if (match(np->jm_node_name,badnodes))
+        if (match(np->jm_node_name, badnodes))
           continue;
 
         /*
@@ -1293,18 +1297,18 @@ static unsigned long nodes_ses(
       if (hit == 0)
         continue;
 
-      sprintf(log_buffer,"rouge pid %d using node(s) %s",
+      sprintf(log_buffer, "rouge pid %d using node(s) %s",
         jp->jm_client_pid,
         jp->jm_node_in_job[0].jm_node_name);
 
-      for (k = 1;k < jp->jm_num_nodes;k++)
+      for (k = 1; k < jp->jm_num_nodes; k++)
         {
         struct JM_NODE_IN_JOB *np = &jp->jm_node_in_job[k];
         int n = strlen(log_buffer);
 
         end = &log_buffer[n];
 
-        sprintf(end,"+%s",
+        sprintf(end, "+%s",
           np->jm_node_name);
         }
 
@@ -1318,8 +1322,9 @@ static unsigned long nodes_ses(
 
   if (strlen(badnodes))
     {
-    sprintf(log_buffer,"node(s) %.450s outside allowed list %.450s",
-      badnodes, 
+    sprintf(log_buffer,
+      "node(s) %.450s outside allowed list %.450s",
+      badnodes,
       nodes);
 
     DBPRT(("%s: %s\n", id, log_buffer))
@@ -1329,7 +1334,7 @@ static unsigned long nodes_ses(
     return(TRUE);
     }
 
-  return(FALSE);
+  return (FALSE);
   }  /* END nodes_ses() */
 
 #endif /* IBM_SP2 */
@@ -1406,8 +1411,8 @@ mom_get_sample(void)
  * Otherwise, return FALSE.
  */
 
-int mom_over_limit(pjob)
-job   *pjob;
+int
+mom_over_limit(job *pjob)
   {
   char  *id = "mom_over_limit";
   char  *pname;
@@ -1437,7 +1442,7 @@ job   *pjob;
     assert(pname != NULL);
     assert(*pname != '\0');
 
-    if (strcmp(pname, "cput") == 0)
+    if ((igncput == FALSE) && (strcmp(pname, "cput") == 0))
       {
       retval = gettime(pres, &value);
 
@@ -1481,7 +1486,7 @@ job   *pjob;
         return (TRUE);
         }
       }
-    else if (strcmp(pname, "walltime") == 0)
+    else if ((ignwalltime == FALSE) && (strcmp(pname, "walltime") == 0))
       {
       if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_HERE) == 0)
         continue;
@@ -1498,9 +1503,7 @@ job   *pjob;
         sprintf(log_buffer,
                 "walltime %d exceeded limit %d",
                 num, value);
-
-        if (ignwalltime == 0)
-          return (TRUE);
+        return (TRUE);
         }
       }
     }
@@ -1517,8 +1520,8 @@ job   *pjob;
  *
  * Assumes that the session ID attribute has already been set.
  */
-int mom_set_use(pjob)
-job   *pjob;
+int
+mom_set_use(job *pjob)
   {
   char   *id = "mom_set_use";
   resource  *pres;
@@ -1612,10 +1615,8 @@ job   *pjob;
  * Kill a task session.
  * Call with the job pointer and a signal number.
  */
-int kill_task(ptask, sig, pg)
-task *ptask;
-int   sig;
-int         pg;
+int
+kill_task(task *ptask, int sig, int pg)
   {
   int ct = 0;
   int i, err;
@@ -1669,14 +1670,13 @@ mom_close_poll(void)
   }
 
 /*
- * mom_does_chkpnt - return 1 if mom supports checkpoint
- *       0 if not
+ * mom_does_checkpoint
  */
 
 int
-mom_does_chkpnt(void)
+mom_does_checkpoint(void)
   {
-  return (0);
+  return(CST_NONE);
   }
 
 /*
@@ -1685,10 +1685,8 @@ mom_does_chkpnt(void)
  * If abort is true, kill it too.
  */
 
-int mach_checkpoint(ptask, file, abort)
-task *ptask;
-char *file;
-int  abort;
+int
+mach_checkpoint(task *ptask, char *file, int abort)
   {
   return (-1);
   }
@@ -1699,9 +1697,8 @@ int  abort;
  * Return a -1 on error or sid.
  */
 
-long mach_restart(ptask, file)
-task *ptask;
-char *file;
+long
+mach_restart(task *ptask, char *file)
   {
   return (-1);
   }
@@ -2206,23 +2203,23 @@ sessions(struct rm_attribute *attrib)
 
     rm_errno = RM_ERR_BADPARAM;
 
-    return(NULL);
+    return (NULL);
     }
 
   if ((nproc = getproctab()) == 0)
     {
     rm_errno = RM_ERR_SYSTEM;
 
-    return(NULL);
+    return (NULL);
     }
 
-  if ((jids = calloc(nproc,sizeof(pid_t))) == NULL)
+  if ((jids = calloc(nproc, sizeof(pid_t))) == NULL)
     {
-    log_err(errno,id,"no memory");
+    log_err(errno, id, "no memory");
 
     rm_errno = RM_ERR_SYSTEM;
 
-    return(NULL);
+    return (NULL);
     }
 
   /*
@@ -2231,6 +2228,7 @@ sessions(struct rm_attribute *attrib)
 
   for (i = 0; i < nproc; i++)
     {
+
     register struct procsinfo *pp = &proc_tbl[i];
 
     if (pp->pi_state == SNONE)
@@ -2430,7 +2428,7 @@ nusers(struct rm_attribute *attrib)
 
   free(uids);
 
-  return(ret_string);
+  return (ret_string);
   }
 
 
@@ -2452,16 +2450,16 @@ int getswap(
 
   if (lastai == reqnum) /* already have anoninfo */
     {
-    return(0);
+    return (0);
     }
 
   swap_free = swap_size = 0;
 
-  for (i = 0;swap_dev[i];i++)
+  for (i = 0; swap_dev[i]; i++)
     {
     if (swapqry(swap_dev[i], &pginfo) == -1)
       {
-      log_err(errno,id,swap_dev[i]);
+      log_err(errno, id, swap_dev[i]);
 
       continue;
       }
