@@ -95,7 +95,7 @@
 #include "server_limits.h"
 #include "attribute.h"
 #include "resource.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "mom_mach.h"
 #include "mom_func.h"
 #include "resmon.h"
@@ -104,7 +104,7 @@
 #include <st_client.h>
 #endif    /* IBM SP2 */
 
-static char ident[] = "@(#) $RCSfile$ $Revision: 2394 $";
+static char ident[] = "@(#) $RCSfile$ $Revision: 2367 $";
 
 /* Global Variables */
 
@@ -129,10 +129,8 @@ static int     job_key;
  *  -2 - if other, message in log_buffer
  */
 
-int set_job(pjob, sjr)
-job *pjob;
-
-struct startjob_rtn *sjr;
+int
+set_job(job *pjob, struct startjob_rtn *sjr)
   {
   return (sjr->sj_session = setsid());
   }
@@ -141,10 +139,7 @@ struct startjob_rtn *sjr;
 ** set_globid - set the global id for a machine type.
 */
 void
-set_globid(pjob, sjr)
-job *pjob;
-
-struct startjob_rtn *sjr;
+set_globid(job *pjob, struct startjob_rtn *sjr)
   {
   extern char noglobid[];
 
@@ -157,10 +152,10 @@ struct startjob_rtn *sjr;
  */
 
 int
-set_mach_vars(pjob, vtab)
-job      *pjob;    /* pointer to the job */
-
-struct var_table *vtab;    /* pointer to variable table */
+set_mach_vars(
+  job *pjob,    /* pointer to the job */
+  struct var_table *vtab    /* pointer to variable table */
+)
   {
 #if IBM_SP2==1 || IBM_SP2==2 /* IBM SP2 with PSSP 2.x or 3.x*/
   char  buf[256];
@@ -194,10 +189,8 @@ struct var_table *vtab;    /* pointer to variable table */
   return 0;
   }
 
-char *set_shell(pjob, pwdp)
-job       *pjob;
-
-struct passwd *pwdp;
+char *
+set_shell(job *pjob, struct passwd *pwdp)
   {
   char *cp;
   int   i;
@@ -468,10 +461,8 @@ name_to_sw_num(char *nn)
   }
 
 
-static int build_swtbl_array(pjob, psa)
-job       *pjob;
-
-struct ST_NODE_INFO **psa;
+static int
+build_swtbl_array(job *pjob, struct ST_NODE_INFO **psa)
   {
   int    i;
   int    j;
@@ -516,8 +507,8 @@ struct ST_NODE_INFO **psa;
  * the value of MP_CHILD passed by IBM's poe.
  */
 
-int load_sp_switch(pjob)
-job *pjob;
+int
+load_sp_switch(job *pjob)
   {
   int       i;
   int       rc = 0;
@@ -585,8 +576,8 @@ job *pjob;
  * Also remove the aux *.SW file created when the switch is loaded above.
  */
 
-void unload_sp_switch(pjob)
-job *pjob;
+void
+unload_sp_switch(job *pjob)
   {
   int       i;
   int       rc = 0;
