@@ -12,7 +12,7 @@
 #include "server_limits.h"
 #include "list_link.h"
 #include "attribute.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "log.h"
 #include "mom_func.h"
 #include "resource.h"
