@@ -149,7 +149,7 @@
 #include "server_limits.h"
 #include "attribute.h"
 #include "resource.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "mom_mach.h"
 #include "resmon.h"
 #include "mom_func.h"
@@ -178,13 +178,14 @@ extern double  wallfactor;
 extern  int     LOGLEVEL;
 extern  long    system_ncpus;
 extern  int     ignwalltime;
+extern  int     igncput;
 extern  int     ignvmem;
+extern  int     ignmem;
 extern char   *ret_string;
 extern char    extra_parm[];
 extern char    no_parm[];
 extern  char   *msg_momsetlim;
 
-extern  struct  pbs_err_to_txt  pbs_err_to_txt[];
 extern  time_t  time_now;
 
 extern char *loadave A_((struct rm_attribute *attrib));
@@ -321,9 +322,8 @@ dep_main_loop_cycle(void)
  *
  */
 
-static int getsize(pres, ret)
-resource  *pres;
-unsigned long *ret;
+static int
+getsize(resource *pres, unsigned long *ret)
   {
   unsigned long value;
 
@@ -358,9 +358,8 @@ unsigned long *ret;
  * decoded value of time in seconds in the unsigned long integer.
  */
 
-static int gettime(pres, ret)
-resource  *pres;
-unsigned long *ret;
+static int
+gettime(resource *pres, unsigned long *ret)
   {
 
   if (pres->rs_value.at_type != ATR_TYPE_LONG)
@@ -647,28 +646,14 @@ int error(
   char *string,
   int value)
   {
-  int  i = 0;
   char  *message;
 
   assert(string != NULL);
   assert(*string != '\0');
-  assert(value > PBSE_);  /* minimum PBS error number */
-  assert(value <= PBSE_NOSYNCMSTR); /* maximum PBS error number */
-  assert(pbs_err_to_txt[i].err_no != 0);
 
-  do
-    {
-    if (pbs_err_to_txt[i].err_no == value)
-      break;
-    }
-  while (pbs_err_to_txt[++i].err_no != 0);
-
-  assert(pbs_err_to_txt[i].err_txt != NULL);
-
-  message = *pbs_err_to_txt[i].err_txt;
+  message = pbse_to_txt(value);
 
   assert(message != NULL);
-
   assert(*message != '\0');
 
   (void)fprintf(stderr, msg_momsetlim, string, message);
@@ -699,9 +684,11 @@ int error(
  * existing limits.  Cannot alter those set by setrlimit (kernel)
  * because we are the wrong process.
  */
-int mom_set_limits(pjob, set_mode)
-job   *pjob;
-int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
+int
+mom_set_limits(
+  job *pjob,
+  int set_mode /* SET_LIMIT_SET or SET_LIMIT_ALTER */
+)
   {
 #ifndef NDEBUG
   char  *id = "mom_set_limits";
@@ -736,25 +723,31 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
 
     if (strcmp(pname, "cput") == 0)
       {
-      /* cpu time - check, if less than pcput use it */
-      retval = gettime(pres, &value);
+      if (igncput == FALSE)
+        {
+        /* cpu time - check, if less than pcput use it */
+        retval = gettime(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
+        }
       }
     else if (strcmp(pname, "pcput") == 0)
       {
-      /* process cpu time - set */
-      retval = gettime(pres, &value);
+      if (igncput == FALSE)
+        {
+        /* process cpu time - set */
+        retval = gettime(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
 
-      reslim.rlim_cur = reslim.rlim_max =
-                          (unsigned long)((double)value / cputfactor);
+        reslim.rlim_cur = reslim.rlim_max =
+          (unsigned long)((double)value / cputfactor);
 
-      if (setrlimit(RLIMIT_CPU, &reslim) < 0)
-        return (error("RLIMIT_CPU", PBSE_SYSTEM));
+        if (setrlimit(RLIMIT_CPU, &reslim) < 0)
+          return (error("RLIMIT_CPU", PBSE_SYSTEM));
+        }
       }
     else if (strcmp(pname, "file") == 0)   /* set */
       {
@@ -776,46 +769,55 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
       }
     else if (strcmp(pname, "vmem") == 0)   /* check */
       {
-      retval = getsize(pres, &value);
-
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
-
-      if ((mem_limit == 0) || (value < mem_limit))
-        mem_limit = value;
-      }
-    else if (strcmp(pname, "pvmem") == 0)   /* set */
-      {
-      if (set_mode == SET_LIMIT_SET)
+      if (ignvmem == FALSE)
         {
         retval = getsize(pres, &value);
 
         if (retval != PBSE_NONE)
           return (error(pname, retval));
 
-        if (value > ULONG_MAX)
-          return (error(pname, PBSE_BADATVAL));
-
         if ((mem_limit == 0) || (value < mem_limit))
           mem_limit = value;
         }
       }
+    else if (strcmp(pname, "pvmem") == 0)   /* set */
+      {
+      if (ignvmem == FALSE)
+        {
+        if (set_mode == SET_LIMIT_SET)
+          {
+          retval = getsize(pres, &value);
+  
+          if (retval != PBSE_NONE)
+            return (error(pname, retval));
+
+          if (value > ULONG_MAX)
+            return (error(pname, PBSE_BADATVAL));
+
+          if ((mem_limit == 0) || (value < mem_limit))
+            mem_limit = value;  
+          }
+        }
+      }
     else if (strcmp(pname, "mem") == 0)    /* ignore */
       {
       }
     else if (strcmp(pname, "pmem") == 0)   /* set */
       {
-      if (set_mode == SET_LIMIT_SET)
+      if (ignmem == FALSE)
         {
-        retval = getsize(pres, &value);
+        if (set_mode == SET_LIMIT_SET)
+          {
+          retval = getsize(pres, &value);
 
-        if (retval != PBSE_NONE)
-          return (error(pname, retval));
+          if (retval != PBSE_NONE)
+            return (error(pname, retval));
 
-        reslim.rlim_cur = reslim.rlim_max = value;
+          reslim.rlim_cur = reslim.rlim_max = value;
 
-        if (setrlimit(RLIMIT_RSS, &reslim) < 0)
-          return (error("RLIMIT_RSS", PBSE_SYSTEM));
+          if (setrlimit(RLIMIT_RSS, &reslim) < 0)
+            return (error("RLIMIT_RSS", PBSE_SYSTEM));
+          }
         }
       }
     else if (strcmp(pname, "walltime") == 0)   /* Check */
@@ -1161,7 +1163,7 @@ int mom_over_limit(
     assert(pname != NULL);
     assert(*pname != '\0');
 
-    if (!strcmp(pname, "cput"))
+    if ((igncput == FALSE) && (!strcmp(pname, "cput")))
       {
       retval = gettime(pres, &value);
 
@@ -1221,7 +1223,7 @@ int mom_over_limit(
         return(TRUE);
         }
       }
-    else if (!strcmp(pname, "walltime"))
+    else if (ignwalltime == 0 && !strcmp(pname, "walltime"))
       {
       if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_HERE) == 0)
         continue;
@@ -1239,8 +1241,7 @@ int mom_over_limit(
         sprintf(log_buffer, "walltime %lu exceeded limit %lu",
                 num, value);
 
-        if (ignwalltime == 0)
-          return(TRUE);
+        return(TRUE);
         }
       }
     }
@@ -1469,13 +1470,12 @@ mom_close_poll(void)
 
 
 /*
- * mom_does_chkpnt - return 1 if mom supports checkpoint
- *       0 if not
+ * mom_does_checkpoint
  */
 int
-mom_does_chkpnt(void)
+mom_does_checkpoint(void)
   {
-  return (0);
+  return(CST_NONE);
   }
 
 /*
