@@ -119,7 +119,7 @@
 #include "server_limits.h"
 #include "attribute.h"
 #include "resource.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "log.h"
 #include "mom_mach.h"
 #include "mom_func.h"
@@ -171,6 +171,7 @@ extern double cputfactor;
 extern  double wallfactor;
 extern  long    system_ncpus;
 extern  int     ignwalltime;
+extern  int     igncput;
 extern  int     ignvmem;
 
 /*
@@ -205,7 +206,6 @@ static long  page_size;
 
 #define TBL_INC 20
 
-extern struct pbs_err_to_txt pbs_err_to_txt[];
 extern time_t   time_now;
 
 extern char extra_parm[];
@@ -279,9 +279,8 @@ dep_cleanup(void)
  *  sizeof(word) = sizeof(int)
  */
 
-static int getsize(pres, ret)
-resource  *pres;
-unsigned long *ret;
+static int
+getsize(resource *pres, unsigned long *ret)
   {
   unsigned long value;
 
@@ -316,9 +315,8 @@ unsigned long *ret;
  * decoded value of time in seconds in the unsigned long integer.
  */
 
-static int gettime(pres, ret)
-resource  *pres;
-unsigned long *ret;
+static int
+gettime(resource *pres, unsigned long *ret)
   {
 
   if (pres->rs_value.at_type != ATR_TYPE_LONG)
@@ -368,8 +366,8 @@ pid_t sid;
  * consumed for all tasks executed by the job, in seconds,
  * adjusted by cputfactor.
  */
-static unsigned long cput_sum(pjob)
-job   *pjob;
+static unsigned long
+cput_sum(job *pjob)
   {
   char   *id = "cput_sum";
   ulong   cputime, addtime;
@@ -418,9 +416,8 @@ job   *pjob;
 /*
  * Return TRUE if any process in the job is over limit for cputime usage.
  */
-static int overcput_proc(pjob, limit)
-job   *pjob;
-unsigned long limit;
+static int
+overcput_proc(job *pjob, unsigned long limit)
   {
   char  *id = "overcput_proc";
   ulong  memsize;
@@ -454,8 +451,8 @@ unsigned long limit;
  * Returns the total number of bytes of address
  * space consumed by all current tasks within the session.
  */
-static unsigned long mem_sum(pjob)
-job   *pjob;
+static unsigned long
+mem_sum(job *pjob)
   {
   char  *id = "mem_sum";
   ulong  memsize;
@@ -480,8 +477,8 @@ job   *pjob;
 /*
  * Internal session mem (workingset) size function.
  */
-static unsigned long resi_sum(pjob)
-job   *pjob;
+static unsigned long
+resi_sum(job *pjob)
   {
   char  *id = "resi_sum";
   ulong  resisize;
@@ -511,28 +508,14 @@ extern char *msg_momsetlim;
 int
 error(char *string, int value)
   {
-  int  i = 0;
   char  *message;
 
   assert(string != NULL);
   assert(*string != '\0');
-  assert(value > PBSE_);   /* minimum PBS error number */
-  assert(value <= PBSE_NOSYNCMSTR); /* maximum PBS error number */
-  assert(pbs_err_to_txt[i].err_no != 0);
 
-  do
-    {
-    if (pbs_err_to_txt[i].err_no == value)
-      break;
-    }
-  while (pbs_err_to_txt[++i].err_no != 0);
-
-  assert(pbs_err_to_txt[i].err_txt != NULL);
-
-  message = *pbs_err_to_txt[i].err_txt;
+  message = pbse_to_txt(value);
 
   assert(message != NULL);
-
   assert(*message != '\0');
 
   (void)fprintf(stderr, msg_momsetlim, string, message);
@@ -563,9 +546,11 @@ error(char *string, int value)
  * existing limits.  Cannot alter those set by setrlimit (kernel)
  * because we are the wrong process.
  */
-int mom_set_limits(pjob, set_mode)
-job   *pjob;
-int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
+int
+mom_set_limits(
+  job *pjob,
+  int set_mode /* SET_LIMIT_SET or SET_LIMIT_ALTER */
+)
   {
   char  *id = "mom_set_limits";
   char  *pname;
@@ -598,25 +583,31 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
 
     if (strcmp(pname, "cput") == 0)
       {
-      /* cpu time - check, if less than pcput use it */
-      retval = gettime(pres, &value);
+      if (igncput == FALSE)
+        {
+        /* cpu time - check, if less than pcput use it */
+        retval = gettime(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
+        }
       }
     else if (strcmp(pname, "pcput") == 0)
       {
-      /* process cpu time - set */
-      retval = gettime(pres, &value);
+      if (igncput == FALSE)
+        {
+        /* process cpu time - set */
+        retval = gettime(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
 
-      reslim.rlim_cur = reslim.rlim_max =
-                          (unsigned long)((double)value / cputfactor);
+        reslim.rlim_cur = reslim.rlim_max =
+          (unsigned long)((double)value / cputfactor);
 
-      if (setrlimit(RLIMIT_CPU, &reslim) < 0)
-        return (error("RLIMIT_CPU", PBSE_SYSTEM));
+        if (setrlimit(RLIMIT_CPU, &reslim) < 0)
+          return (error("RLIMIT_CPU", PBSE_SYSTEM));
+        }
       }
     else if (!strcmp(pname, "file"))
       {
@@ -646,30 +637,36 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
       }
     else if (strcmp(pname, "vmem") == 0)  /* check */
       {
-      retval = getsize(pres, &value);
-
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
-
-      if ((mem_limit == 0) || (value < mem_limit))
-        mem_limit = value;
-      }
-    else if (strcmp(pname, "pvmem") == 0)   /* set */
-      {
-      if (set_mode == SET_LIMIT_SET)
+      if (ignvmem == FALSE)
         {
         retval = getsize(pres, &value);
 
         if (retval != PBSE_NONE)
           return (error(pname, retval));
 
-        if (value > ULONG_MAX)
-          return (error(pname, PBSE_BADATVAL));
-
         if ((mem_limit == 0) || (value < mem_limit))
           mem_limit = value;
         }
       }
+    else if (strcmp(pname, "pvmem") == 0)   /* set */
+      {
+      if (ignvmem == FALSE)
+        {
+        if (set_mode == SET_LIMIT_SET)
+          {
+          retval = getsize(pres, &value);
+
+          if (retval != PBSE_NONE)
+            return (error(pname, retval));
+
+          if (value > ULONG_MAX)
+            return (error(pname, PBSE_BADATVAL));
+
+          if ((mem_limit == 0) || (value < mem_limit))
+            mem_limit = value;
+          }
+        }
+      }
     else if (strcmp(pname, "mem") == 0)    /* ignore */
       {
       }
@@ -725,8 +722,8 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
  * polling is done using the mom_over_limit machine-dependent function.
  */
 
-int mom_do_poll(pjob)
-job   *pjob;
+int
+mom_do_poll(job *pjob)
   {
   char  *id = "mom_do_poll";
   char  *pname;
@@ -865,8 +862,8 @@ mom_get_sample(void)
  * Otherwise, return FALSE.
  */
 
-int mom_over_limit(pjob)
-job   *pjob;
+int
+mom_over_limit(job *pjob)
   {
   char  *id = "mom_over_limit";
   char  *pname;
@@ -888,7 +885,7 @@ job   *pjob;
     assert(pname != NULL);
     assert(*pname != '\0');
 
-    if (strcmp(pname, "cput") == 0)
+    if ((igncput == FALSE) && (strcmp(pname, "cput") == 0))
       {
       retval = gettime(pres, &value);
 
@@ -903,7 +900,7 @@ job   *pjob;
         return (TRUE);
         }
       }
-    else if (strcmp(pname, "pcput") == 0)
+    else if ((igncput == FALSE) && (strcmp(pname, "pcput") == 0))
       {
       retval = gettime(pres, &value);
 
@@ -933,7 +930,7 @@ job   *pjob;
         return (TRUE);
         }
       }
-    else if (strcmp(pname, "walltime") == 0)
+    else if (ignwalltime == 0 && strcmp(pname, "walltime") == 0)
       {
       if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_HERE) == 0)
         continue;
@@ -950,9 +947,7 @@ job   *pjob;
         sprintf(log_buffer,
                 "walltime %lu exceeded limit %lu",
                 num, value);
-
-        if (ignwalltime == 0)
-          return (TRUE);
+        return (TRUE);
         }
       }
     }
@@ -969,8 +964,8 @@ job   *pjob;
  *
  * Assumes that the session ID attribute has already been set.
  */
-int mom_set_use(pjob)
-job   *pjob;
+int
+mom_set_use(job *pjob)
   {
   char   *id = "mom_set_use";
   resource  *pres;
@@ -1039,10 +1034,8 @@ job   *pjob;
  * Kill a task session.
  * Call with the task pointer and a signal number.
  */
-int kill_task(ptask, sig, pg)
-task *ptask;
-int   sig;
-int         pg;
+int
+kill_task(task *ptask, int sig, int pg)
   {
   char  *id = "kill_task";
   int  ct = 0;
@@ -1101,14 +1094,13 @@ mom_close_poll(void)
   }
 
 /*
- * mom_does_chkpnt - return 1 if mom supports checkpoint
- *       0 if not
+ * mom_does_checkpoint
  */
 
 int
-mom_does_chkpnt(void)
+mom_does_checkpoint(void)
   {
-  return (0);
+  return(CST_NONE);
   }
 
 /*
@@ -1117,10 +1109,8 @@ mom_does_chkpnt(void)
  * If abort is true, kill it too.
  */
 
-int mach_checkpoint(ptask, file, abort)
-task *ptask;
-char *file;
-int  abort;
+int
+mach_checkpoint(task *ptask, char *file, int abort)
   {
   return (-1);
   }
@@ -1131,9 +1121,8 @@ int  abort;
  * Return a PBS error code.
  */
 
-long mach_restart(ptask, file)
-task *ptask;
-char *file;
+long
+mach_restart(task *ptask, char *file)
   {
   return (-1);
   }
