@@ -93,11 +93,11 @@
 #include "server_limits.h"
 #include "attribute.h"
 #include "resource.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "mom_mach.h"
 #include "mom_func.h"
 
-static char ident[] = "@(#) $RCSfile$ $Revision: 2394 $";
+static char ident[] = "@(#) $RCSfile$ $Revision: 2367 $";
 
 /* Global Variables */
 
@@ -118,10 +118,8 @@ extern int  termin_child;
  *  -2 - if other, message in log_buffer
  */
 
-int set_job(pjob, sjr)
-job *pjob;
-
-struct startjob_rtn *sjr;
+int
+set_job(job *pjob, struct startjob_rtn *sjr)
   {
   return (sjr->sj_session = setsid());
   }
@@ -130,10 +128,7 @@ struct startjob_rtn *sjr;
 ** set_globid - set the global id for a machine type.
 */
 void
-set_globid(pjob, sjr)
-job *pjob;
-
-struct startjob_rtn *sjr;
+set_globid(job *pjob, struct startjob_rtn *sjr)
   {
   extern char noglobid[];
 
@@ -146,18 +141,16 @@ struct startjob_rtn *sjr;
  */
 
 int
-set_mach_vars(pjob, vtab)
-job      *pjob;    /* pointer to the job */
-
-struct var_table *vtab;    /* pointer to variable table */
+set_mach_vars(
+  job *pjob,    /* pointer to the job */
+  struct var_table *vtab    /* pointer to variable table */
+)
   {
   return 0;
   }
 
-char *set_shell(pjob, pwdp)
-job       *pjob;
-
-struct passwd *pwdp;
+char *
+set_shell(job *pjob, struct passwd *pwdp)
   {
   char *cp;
   int   i;
