@@ -138,7 +138,7 @@
 #include "server_limits.h"
 #include "attribute.h"
 #include "resource.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "mom_mach.h"
 #include "resmon.h"
 #include "../rm_dep.h"
@@ -161,6 +161,7 @@ extern double cputfactor;
 extern double wallfactor;
 extern  long    system_ncpus;
 extern  int     ignwalltime;
+extern  int     igncput;
 extern  int     ignvmem;
 
 extern  int     LOGLEVEL;
@@ -275,7 +276,6 @@ dep_main_loop_cycle(void)
   /* No periodic functions. */
   }
 
-extern struct pbs_err_to_txt pbs_err_to_txt[];
 extern time_t   time_now;
 
 /*
@@ -304,9 +304,8 @@ extern time_t   time_now;
  *  sizeof(word) = sizeof(int)
  */
 
-static int getsize(pres, ret)
-resource  *pres;
-unsigned long *ret;
+static int
+getsize(resource *pres, unsigned long *ret)
   {
   unsigned long value;
 
@@ -341,9 +340,8 @@ unsigned long *ret;
  * decoded value of time in seconds in the unsigned long integer.
  */
 
-static int gettime(pres, ret)
-resource  *pres;
-unsigned long *ret;
+static int
+gettime(resource *pres, unsigned long *ret)
   {
 
   if (pres->rs_value.at_type != ATR_TYPE_LONG)
@@ -392,8 +390,8 @@ pid_t sesid;
  * Accepts a job id.  Returns the sum of all cpu time consumed for all
  * tasks executed by the job, in seconds, adjusted by cputfactor.
  */
-static unsigned long cput_sum(pjob)
-job  *pjob;
+static unsigned long
+cput_sum(job *pjob)
   {
   static char  id[] = "cput_sum";
   int   i;
@@ -475,8 +473,8 @@ job  *pjob;
  * Accepts a job ID.  Returns the total number of bytes of address
  * space consumed by all current tasks within the job.
  */
-static unsigned long mem_sum(pjob)
-job  *pjob;
+static unsigned long
+mem_sum(job *pjob)
   {
   char  *id = "mem_sum";
   int  i;
@@ -506,8 +504,8 @@ job  *pjob;
 /*
  * Internal session mem (workingset) size function.
  */
-static unsigned long resi_sum(pjob)
-job  *pjob;
+static unsigned long
+resi_sum(job *pjob)
   {
   char  *id = "resi_sum";
   int  i;
@@ -536,9 +534,8 @@ job  *pjob;
 /*
  * Return TRUE if any task in the job is over limit for memory usage.
  */
-static int overmem_proc(pjob, limit)
-job   *pjob;
-unsigned long limit;
+static int
+overmem_proc(job *pjob, unsigned long limit)
   {
   int   i;
 
@@ -567,28 +564,14 @@ extern char *msg_momsetlim;
 int
 error(char *string, int value)
   {
-  int  i = 0;
   char  *message;
 
   assert(string != NULL);
   assert(*string != '\0');
-  assert(value > PBSE_);   /* minimum PBS error number */
-  assert(value <= PBSE_NOSYNCMSTR); /* maximum PBS error number */
-  assert(pbs_err_to_txt[i].err_no != 0);
 
-  do
-    {
-    if (pbs_err_to_txt[i].err_no == value)
-      break;
-    }
-  while (pbs_err_to_txt[++i].err_no != 0);
-
-  assert(pbs_err_to_txt[i].err_txt != NULL);
-
-  message = *pbs_err_to_txt[i].err_txt;
+  message = pbse_to_txt(value);
 
   assert(message != NULL);
-
   assert(*message != '\0');
 
   (void)fprintf(stderr, msg_momsetlim, string, message);
@@ -619,9 +602,11 @@ error(char *string, int value)
  * existing limits.  Cannot alter those set by setrlimit (kernel)
  * because we are the wrong process.
  */
-int mom_set_limits(pjob, set_mode)
-job   *pjob;
-int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
+int
+mom_set_limits(
+  job *pjob,
+  int set_mode /* SET_LIMIT_SET or SET_LIMIT_ALTER */
+)
   {
   char  *id = "mom_set_limits";
   char  *pname;
@@ -654,25 +639,31 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
 
     if (strcmp(pname, "cput") == 0)
       {
-      /* cpu time - check, if less than pcput use it */
-      retval = gettime(pres, &value);
+      if (igncput == FALSE)
+        {
+        /* cpu time - check, if less than pcput use it */
+        retval = gettime(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
+        }
       }
     else if (strcmp(pname, "pcput") == 0)
       {
-      /* process cpu time - set */
-      retval = gettime(pres, &value);
+      if (igncput == FALSE)
+        {
+        /* process cpu time - set */
+        retval = gettime(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
 
-      reslim.rlim_cur = reslim.rlim_max =
-                          (unsigned long)((double)value / cputfactor);
+        reslim.rlim_cur = reslim.rlim_max =
+          (unsigned long)((double)value / cputfactor);
 
-      if (setrlimit(RLIMIT_CPU, &reslim) < 0)
-        return (error("RLIMIT_CPU", PBSE_SYSTEM));
+        if (setrlimit(RLIMIT_CPU, &reslim) < 0)
+          return (error("RLIMIT_CPU", PBSE_SYSTEM));
+        }
       }
     else if (strcmp(pname, "file") == 0)   /* set */
       {
@@ -694,46 +685,55 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
       }
     else if (strcmp(pname, "vmem") == 0)   /* check */
       {
-      retval = getsize(pres, &value);
-
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
-
-      if ((mem_limit == 0) || (value < mem_limit))
-        mem_limit = value;
-      }
-    else if (strcmp(pname, "pvmem") == 0)   /* set */
-      {
-      if (set_mode == SET_LIMIT_SET)
+      if (ignvmem == FALSE)
         {
         retval = getsize(pres, &value);
 
         if (retval != PBSE_NONE)
           return (error(pname, retval));
 
-        if (value > ULONG_MAX)
-          return (error(pname, PBSE_BADATVAL));
-
         if ((mem_limit == 0) || (value < mem_limit))
           mem_limit = value;
         }
       }
+    else if (strcmp(pname, "pvmem") == 0)   /* set */
+      {
+      if (ignvmem == FALSE)
+        {
+        if (set_mode == SET_LIMIT_SET)
+          {
+          retval = getsize(pres, &value);
+
+          if (retval != PBSE_NONE)
+            return (error(pname, retval));
+
+          if (value > ULONG_MAX)
+            return (error(pname, PBSE_BADATVAL));
+
+          if ((mem_limit == 0) || (value < mem_limit))
+            mem_limit = value;
+          }
+        }
+      }
     else if (strcmp(pname, "mem") == 0)    /* ignore */
       {
       }
     else if (strcmp(pname, "pmem") == 0)   /* set */
       {
-      if (set_mode == SET_LIMIT_SET)
+      if (ignmem == FALSE)
         {
-        retval = getsize(pres, &value);
+        if (set_mode == SET_LIMIT_SET)
+          {
+          retval = getsize(pres, &value);
 
-        if (retval != PBSE_NONE)
-          return (error(pname, retval));
+          if (retval != PBSE_NONE)
+            return (error(pname, retval));
 
-        reslim.rlim_cur = reslim.rlim_max = value;
+          reslim.rlim_cur = reslim.rlim_max = value;
 
-        if (setrlimit(RLIMIT_RSS, &reslim) < 0)
-          return (error("RLIMIT_RSS", PBSE_SYSTEM));
+          if (setrlimit(RLIMIT_RSS, &reslim) < 0)
+            return (error("RLIMIT_RSS", PBSE_SYSTEM));
+          }
         }
       }
     else if (strcmp(pname, "walltime") == 0)   /* Check */
@@ -787,8 +787,8 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
  * polling is done using the mom_over_limit machine-dependent function.
  */
 
-int mom_do_poll(pjob)
-job   *pjob;
+int
+mom_do_poll(job *pjob)
   {
   char  *id = "mom_do_poll";
   char  *pname;
@@ -959,8 +959,8 @@ mom_get_sample(void)
  * Otherwise, return FALSE.
  */
 
-int mom_over_limit(pjob)
-job   *pjob;
+int
+mom_over_limit(job *pjob)
   {
   char  *id = "mom_over_limit";
   char  *pname;
@@ -982,7 +982,7 @@ job   *pjob;
     assert(pname != NULL);
     assert(*pname != '\0');
 
-    if (strcmp(pname, "cput") == 0)
+    if ((igncput == FALSE) && (strcmp(pname, "cput") == 0))
       {
       retval = gettime(pres, &value);
 
@@ -1026,7 +1026,7 @@ job   *pjob;
         return (TRUE);
         }
       }
-    else if (strcmp(pname, "walltime") == 0)
+    else if (ignwalltime == 0 && strcmp(pname, "walltime") == 0)
       {
       if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_HERE) == 0)
         continue;
@@ -1043,9 +1043,7 @@ job   *pjob;
         sprintf(log_buffer,
                 "walltime %d exceeded limit %d",
                 num, value);
-
-        if (ignwalltime == 0)
-          return (TRUE);
+        return (TRUE);
         }
       }
     }
@@ -1062,8 +1060,8 @@ job   *pjob;
  *
  * Assumes that the session ID attribute has already been set.
  */
-int mom_set_use(pjob)
-job  *pjob;
+int
+mom_set_use(job *pjob)
   {
   char  *id = "mom_set_use";
   resource *pres;
@@ -1157,10 +1155,8 @@ job  *pjob;
  * Kill a job task.
  * Call with the job and a signal number.
  */
-int kill_task(ptask, sig, pg)
-task *ptask;
-int  sig;
-int         pg;
+int
+kill_task(task *ptask, int sig, int pg)
   {
   char *id = "kill_task";
   int ct = 0;
@@ -1220,14 +1216,13 @@ mom_close_poll(void)
   }
 
 /*
- * mom_does_chkpnt - return 1 if mom supports checkpoint
- *       0 if not
+ * mom_does_checkpoint
  */
 
 int
-mom_does_chkpnt(void)
+mom_does_checkpoint(void)
   {
-  return (0);
+  return(CST_NONE);
   }
 
 /*
@@ -1236,10 +1231,8 @@ mom_does_chkpnt(void)
  * If abort is true, kill it too.
  */
 
-int mach_checkpoint(ptask, file, abort)
-task *ptask;
-char *file;
-int  abort;
+int
+mach_checkpoint(task *ptask, char *file, int abort)
   {
   return (-1);
   }
@@ -1250,9 +1243,8 @@ int  abort;
  * Return -1 on error or sid if okay.
  */
 
-long mach_restart(ptask, file)
-task *ptask;
-char *file;
+long
+mach_restart(task *ptask, char *file)
   {
   return (-1);
   }
