@@ -95,7 +95,7 @@
 #include "server_limits.h"
 #include "attribute.h"
 #include "resource.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "mom_mach.h"
 #include "mom_func.h"
 
@@ -126,10 +126,8 @@ job *TJCache[TMAX_TJCACHESIZE];
  *  -2 - if other, message in log_buffer
  */
 
-int set_job(pjob, sjr)
-job *pjob;
-
-struct startjob_rtn *sjr;
+int
+set_job(job *pjob, struct startjob_rtn *sjr)
   {
   return (sjr->sj_session = setsid());
   }
@@ -138,10 +136,7 @@ struct startjob_rtn *sjr;
 ** set_globid - set the global id for a machine type.
 */
 void
-set_globid(pjob, sjr)
-job *pjob;
-
-struct startjob_rtn *sjr;
+set_globid(job *pjob, struct startjob_rtn *sjr)
   {
   extern char noglobid[];
 
@@ -153,18 +148,16 @@ struct startjob_rtn *sjr;
  * set_mach_vars - setup machine dependent environment variables
  */
 int
-set_mach_vars(pjob, vtab)
-job      *pjob;    /* pointer to the job */
-
-struct var_table *vtab;    /* pointer to variable table */
+set_mach_vars(
+  job *pjob,    /* pointer to the job */
+  struct var_table *vtab    /* pointer to variable table */
+)
   {
   return 0;
   }
 
-char *set_shell(pjob, pwdp)
-job       *pjob;
-
-struct passwd *pwdp;
+char *
+set_shell(job *pjob, struct passwd *pwdp)
   {
   char *cp;
   int   i;
@@ -219,13 +212,6 @@ scan_for_terminated(void)
   task  *ptask = 0;
   int  statloc;
 
-
-#ifdef CACHEOBITFAILURES
-  int tjcindex;
-
-  int TJCIndex = 0;
-#endif
-
   if (LOGLEVEL >= 7)
     {
     log_record(
@@ -251,62 +237,6 @@ scan_for_terminated(void)
       }
     }
 
-#ifdef CACHEOBITFAILURES
-  /* process cached obit failures */
-
-  for (TJCIndex = 0;TJCIndex < TMAX_TJCACHESIZE;TJCIndex++)
-    {
-    if (TJCache[TJCIndex] == NULL)
-      break;
-
-    if (TJCache[TJCIndex] == (job *)1)
-      continue;
-
-    /* attempt to send obit again */
-
-    pjob = TJCache[TJCIndex];
-
-    if (LOGLEVEL >= 7)
-      {
-      LOG_EVENT(
-        PBSEVENT_DEBUG,
-        PBS_EVENTCLASS_JOB,
-        pjob->ji_qs.ji_jobid,
-        "Retrying send of OBIT");
-      }
-
-    if (pjob->ji_mompost(pjob, exiteval) != 0)
-      {
-      /* attempt failed again */
-
-      termin_child = 1;
-
-      continue;
-      }
-
-    /* success */
-    if (LOGLEVEL >= 7)
-      {
-      LOG_EVENT(
-        PBSEVENT_DEBUG,
-        PBS_EVENTCLASS_JOB,
-        pjob->ji_qs.ji_jobid,
-        "OBIT resent successfully");
-      }
-
-    pjob->ji_mompost = NULL;
-
-    /* clear mom sub-task */
-
-    pjob->ji_momsubt = 0;
-
-    job_save(pjob, SAVEJOB_QUICK);
-    TJCache[TJCIndex] = ((job *)1);
-
-    }  /* END for (TJIndex) */
-
-#endif /* CACHEOBITFAILURES */
-
   /* Now figure out which task(s) have terminated (are zombies) */
 
   while ((pid = waitpid(-1, &statloc, WNOHANG)) > 0)
@@ -400,34 +330,6 @@ scan_for_terminated(void)
           pjob->ji_mompost = 0;
           }
 
-#ifdef CACHEOBITFAILURES
-        else
-          {
-          for (tjcindex = 0;tjcindex < TMAX_TJCACHESIZE;tjcindex++)
-            {
-            if ((TJCache[tjcindex] == NULL) || (TJCache[tjcindex] == (job *)1))
-              {
-              if (LOGLEVEL >= 7)
-                {
-                LOG_EVENT(
-                  PBSEVENT_DEBUG,
-                  PBS_EVENTCLASS_JOB,
-                  pjob->ji_qs.ji_jobid,
-                  "Caching OBIT for resend");
-                }
-
-              TJCache[tjcindex] = pjob;
-
-              termin_child = 1;
-
-              break;
-              }
-            }    /* END for (tjcindex) */
-
-          continue;
-          }
-
-#endif /* CACHEOBITFAILURES */
         }
       else
         {
@@ -489,35 +391,6 @@ scan_for_terminated(void)
 
 
 
-/**
- * Removes any cached obits relating to the given job.
- */
-void remove_job_from_obit_cache(
-
-  job *pjob)  /* I */
-
-  { 
-#ifdef CACHEOBITFAILURES
-  int TJCIndex;
-
-  /* remove any reference to this job in the obit cache */
-
-  for (TJCIndex = 0;TJCIndex < TMAX_TJCACHESIZE;TJCIndex++)
-    {
-    if (TJCache[TJCIndex] == NULL)
-      break;
-
-    if (TJCache[TJCIndex] == (job *)1)
-      continue;
-
-    if (TJCache[TJCIndex] == pjob)
-      TJCache[TJCIndex] = (job *)1;  /* clear slot */
-    }
-#endif /* CACHEOBITFAILURES */
-  }  /* END remove_job_from_obit_cache() */
-
-
-
 
 /*
  * creat the master pty, this particular
