@@ -107,7 +107,7 @@
 #include "server_limits.h"
 #include "attribute.h"
 #include "resource.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "log.h"
 #include "mom_mach.h"
 #include "resmon.h"
@@ -137,7 +137,7 @@
 **  valid_user is user name valid..
 */
 
-static char ident[] = "@(#) hpux10/$RCSfile$ $Revision: 2628 $";
+static char ident[] = "@(#) hpux10/$RCSfile$ $Revision: 3151 $";
 
 #ifndef TRUE
 #define FALSE 0
@@ -161,6 +161,7 @@ extern double cputfactor;
 extern double wallfactor;
 extern  long    system_ncpus;
 extern  int     ignwalltime;
+extern  int     igncput;
 extern  int     ignvmem;
 
 /*
@@ -187,7 +188,6 @@ struct pst_status *proc_status = NULL;
 
 #define TBL_INC 20
 
-extern struct pbs_err_to_txt pbs_err_to_txt[];
 extern time_t   time_now;
 
 extern char extra_parm[];
@@ -249,9 +249,8 @@ dep_cleanup(void)
  *  sizeof(word) = sizeof(int)
  */
 
-static int getsize(pres, ret)
-resource  *pres;
-unsigned long *ret;
+static int
+getsize(resource *pres, unsigned long *ret)
   {
   unsigned long value;
 
@@ -286,9 +285,8 @@ unsigned long *ret;
  * decoded value of time in seconds in the unsigned long integer.
  */
 
-static int gettime(pres, ret)
-resource  *pres;
-unsigned long *ret;
+static int
+gettime(resource *pres, unsigned long *ret)
   {
 
   if (pres->rs_value.at_type != ATR_TYPE_LONG)
@@ -337,8 +335,8 @@ pid_t sid;
  * Accepts a job pointer.  Returns the sum of all cpu time
  * consumed for all tasks executed by the job, in seconds.
  */
-static unsigned long cput_sum(pjob)
-job   *pjob;
+static unsigned long
+cput_sum(job *pjob)
   {
   char   *id = "cput_sum";
   unsigned long  cputime, addtime;
@@ -386,9 +384,8 @@ job   *pjob;
 /*
  * Return TRUE if any process in the job is over limit for cputime usage.
  */
-static int overcput_proc(pjob, limit)
-job   *pjob;
-unsigned long limit;
+static int
+overcput_proc(job *pjob, unsigned long limit)
   {
   char          *id = "overcput_proc";
   unsigned long         memsize;
@@ -426,8 +423,8 @@ unsigned long limit;
  * Returns the total number of bytes of address
  * space consumed by all current tasks within the session.
  */
-static unsigned long mem_sum(pjob)
-job   *pjob;
+static unsigned long
+mem_sum(job *pjob)
   {
   char          *id = "mem_sum";
   unsigned long         memsize;
@@ -453,8 +450,8 @@ job   *pjob;
 /*
  * Internal session mem (workingset) size function.
  */
-static unsigned long resi_sum(pjob)
-job   *pjob;
+static unsigned long
+resi_sum(job *pjob)
   {
   char          *id = "resi_sum";
   unsigned long         resisize;
@@ -485,28 +482,14 @@ extern char *msg_momsetlim;
 int
 error(char *string, int value)
   {
-  int  i = 0;
   char  *message;
 
   assert(string != NULL);
   assert(*string != '\0');
-  assert(value > PBSE_);   /* minimum PBS error number */
-  assert(value <= PBSE_NOSYNCMSTR); /* maximum PBS error number */
-  assert(pbs_err_to_txt[i].err_no != 0);
 
-  do
-    {
-    if (pbs_err_to_txt[i].err_no == value)
-      break;
-    }
-  while (pbs_err_to_txt[++i].err_no != 0);
-
-  assert(pbs_err_to_txt[i].err_txt != NULL);
-
-  message = *pbs_err_to_txt[i].err_txt;
+  message = pbse_to_txt(value);
 
   assert(message != NULL);
-
   assert(*message != '\0');
 
   (void)fprintf(stderr, msg_momsetlim, string, message);
@@ -537,9 +520,11 @@ error(char *string, int value)
  * existing limits.  Cannot alter those set by setrlimit (kernel)
  * because we are the wrong process.
  */
-int mom_set_limits(pjob, set_mode)
-job   *pjob;
-int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
+int
+mom_set_limits(
+  job *pjob,
+  int set_mode /* SET_LIMIT_SET or SET_LIMIT_ALTER */
+)
   {
   char  *id = "mom_set_limits";
   char  *pname;
@@ -572,25 +557,31 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
 
     if (strcmp(pname, "cput") == 0)
       {
-      /* cpu time - check, if less than pcput use it */
-      retval = gettime(pres, &value);
+      if (igncput == FALSE)
+        {
+        /* cpu time - check, if less than pcput use it */
+        retval = gettime(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
+        }
       }
     else if (strcmp(pname, "pcput") == 0)
       {
-      /* process cpu time - set */
-      retval = gettime(pres, &value);
+      if (igncput == FALSE)
+        {
+        /* process cpu time - set */
+        retval = gettime(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
 
-      reslim.rlim_cur = reslim.rlim_max =
-                          (unsigned long)((double)value / cputfactor);
+        reslim.rlim_cur = reslim.rlim_max =
+          (unsigned long)((double)value / cputfactor);
 
-      if (setrlimit(RLIMIT_CPU, &reslim) < 0)
-        return (error("RLIMIT_CPU", PBSE_SYSTEM));
+        if (setrlimit(RLIMIT_CPU, &reslim) < 0)
+          return (error("RLIMIT_CPU", PBSE_SYSTEM));
+        }
       }
     else if (strcmp(pname, "file") == 0)   /* set */
       {
@@ -612,30 +603,36 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
       }
     else if (strcmp(pname, "vmem") == 0)   /* check */
       {
-      retval = getsize(pres, &value);
-
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
-
-      if ((mem_limit == 0) || (value < mem_limit))
-        mem_limit = value;
-      }
-    else if (strcmp(pname, "pvmem") == 0)   /* set */
-      {
-      if (set_mode == SET_LIMIT_SET)
+      if (ignvmem == FALSE)
         {
         retval = getsize(pres, &value);
 
         if (retval != PBSE_NONE)
           return (error(pname, retval));
 
-        if (value > INT_MAX)
-          return (error(pname, PBSE_BADATVAL));
-
         if ((mem_limit == 0) || (value < mem_limit))
           mem_limit = value;
         }
       }
+    else if (strcmp(pname, "pvmem") == 0)   /* set */
+      {
+      if (ignvmem == FALSE)
+        {
+        if (set_mode == SET_LIMIT_SET)
+          {
+          retval = getsize(pres, &value);
+
+          if (retval != PBSE_NONE)
+            return (error(pname, retval));
+
+          if (value > INT_MAX)
+            return (error(pname, PBSE_BADATVAL));
+
+          if ((mem_limit == 0) || (value < mem_limit))
+            mem_limit = value;
+          }
+        }
+      }
     else if (strcmp(pname, "walltime") == 0)   /* Check */
       {
       retval = gettime(pres, &value);
@@ -684,8 +681,8 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
  * polling is done using the mom_over_limit machine-dependent function.
  */
 
-int mom_do_poll(pjob)
-job   *pjob;
+int
+mom_do_poll(job *pjob)
   {
   char  *id = "mom_do_poll";
   char  *pname;
@@ -782,8 +779,8 @@ mom_get_sample(void)
  * Otherwise, return FALSE.
  */
 
-int mom_over_limit(pjob)
-job   *pjob;
+int
+mom_over_limit(job *pjob)
   {
   char  *id = "mom_over_limit";
   char  *pname;
@@ -805,7 +802,7 @@ job   *pjob;
     assert(pname != NULL);
     assert(*pname != '\0');
 
-    if (strcmp(pname, "cput") == 0)
+    if ((igncput == FALSE) && (strcmp(pname, "cput") == 0))
       {
       retval = gettime(pres, &value);
 
@@ -820,7 +817,7 @@ job   *pjob;
         return (TRUE);
         }
       }
-    else if (strcmp(pname, "pcput") == 0)
+    else if ((igncput == FALSE) && (strcmp(pname, "pcput") == 0))
       {
       retval = gettime(pres, &value);
 
@@ -850,7 +847,7 @@ job   *pjob;
         return (TRUE);
         }
       }
-    else if (strcmp(pname, "walltime") == 0)
+    else if (ignwalltime == 0 && strcmp(pname, "walltime") == 0)
       {
       if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_HERE) == 0)
         continue;
@@ -867,9 +864,7 @@ job   *pjob;
         sprintf(log_buffer,
                 "walltime %d exceeded limit %d",
                 num, value);
-
-        if (ignwalltime == 0)
-          return (TRUE);
+        return (TRUE);
         }
       }
     }
@@ -886,8 +881,8 @@ job   *pjob;
  *
  * Assumes that the session ID attribute has already been set.
  */
-int mom_set_use(pjob)
-job   *pjob;
+int
+mom_set_use(job *pjob)
   {
   char   *id = "mom_set_use";
   resource  *pres;
@@ -956,10 +951,8 @@ job   *pjob;
  * Kill a task session.
  * Call with the task pointer and a signal number.
  */
-int kill_task(ptask, sig, pg)
-task *ptask;
-int   sig;
-int         pg;
+int
+kill_task(task *ptask, int sig, int pg)
   {
   char          *id = "kill_task";
   int          ct = 0;
@@ -1006,14 +999,13 @@ mom_close_poll(void)
   }
 
 /*
- * mom_does_chkpnt - return 1 if mom supports checkpoint
- *       0 if not
+ * mom_does_checkpoint
  */
 
 int
-mom_does_chkpnt(void)
+mom_does_checkpoint(void)
   {
-  return (0);
+  return(CST_NONE);
   }
 
 /*
@@ -1022,10 +1014,8 @@ mom_does_chkpnt(void)
  * If abort is true, kill it too.  Return -1 on error.
  */
 
-int mach_checkpoint(ptask, file, abort)
-task *ptask;
-char *file;
-int  abort;
+int
+mach_checkpoint(task *ptask, char *file, int abort)
   {
   return (-1);
   }
@@ -1034,9 +1024,8 @@ int  abort;
  * Restart the job from the checkpoint file.
  */
 
-long mach_restart(ptask, file)
-task *ptask;
-char *file;
+long
+mach_restart(task *ptask, char *file)
   {
   return (-1);
   }
