@@ -106,7 +106,7 @@
 #include "server_limits.h"
 #include "attribute.h"
 #include "resource.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "log.h"
 #include "mom_mach.h"
 #include "resmon.h"
@@ -135,7 +135,7 @@
 **  quota  quota information (sizes in KB)
 */
 
-static char ident[] = "@(#) sgi/$RCSfile$ $Revision: 2628 $";
+static char ident[] = "@(#) sgi/$RCSfile$ $Revision: 3151 $";
 
 #ifndef TRUE
 #define FALSE 0
@@ -159,7 +159,6 @@ time_t  wait_time = 10;
 extern char extra_parm[];
 extern char no_parm[];
 
-extern struct pbs_err_to_txt pbs_err_to_txt[];
 extern time_t   time_now;
 
 /*
@@ -174,7 +173,9 @@ extern double cputfactor;
 extern double wallfactor;
 extern  long    system_ncpus;
 extern  int     ignwalltime;
+extern  int     igncput;
 extern  int     ignvmem;
+extern  int     ignmem;
 
 /*
 ** local functions and data
@@ -296,9 +297,8 @@ dep_main_loop_cycle(void)
  *  sizeof(word) = sizeof(int)
  */
 
-static int getsize(pres, ret)
-resource  *pres;
-unsigned long *ret;
+static int
+getsize(resource *pres, unsigned long *ret)
   {
   unsigned long value;
 
@@ -333,9 +333,8 @@ unsigned long *ret;
  * decoded value of time in seconds in the unsigned long integer.
  */
 
-static int gettime(pres, ret)
-resource  *pres;
-unsigned long *ret;
+static int
+gettime(resource *pres, unsigned long *ret)
   {
 
   if (pres->rs_value.at_type != ATR_TYPE_LONG)
@@ -360,11 +359,8 @@ unsigned long *ret;
 ** Scan a list of tasks and return true if one of them matches
 ** the process (sid or pid) represented by *psp.
 */
-static
-int
-injob(phead, psp)
-tlist_head *phead;
-prpsinfo_t *psp;
+static int
+injob(tlist_head *phead, prpsinfo_t *psp)
   {
   task  *ptask;
   pid_t  key;
@@ -393,8 +389,8 @@ prpsinfo_t *psp;
  * adjusted by cputfactor.
  */
 
-static unsigned long cput_sum(phead)
-tlist_head *phead;
+static unsigned long
+cput_sum(tlist_head *phead)
   {
   char   *id = "cput_sum";
   int   fd;
@@ -451,9 +447,8 @@ tlist_head *phead;
 /*
  * Return TRUE if any process in the job is over limit for cputime usage.
  */
-static int overcpu_proc(phead, limit)
-tlist_head  *phead;
-unsigned long limit;
+static int
+overcpu_proc(tlist_head *phead, unsigned long limit)
   {
   char  *id = "overcpu_proc";
   int  fd;
@@ -498,8 +493,8 @@ unsigned long limit;
  * Returns the total number of bytes of address
  * space consumed by all current tasks within the list of tasks.
  */
-static unsigned long mem_sum(phead)
-tlist_head *phead;
+static unsigned long
+mem_sum(tlist_head *phead)
   {
   static char  id[] = "mem_sum";
   int   fd;
@@ -555,8 +550,8 @@ tlist_head *phead;
 /*
  * Internal session mem (workingset) size function.
  */
-static unsigned long resi_sum(phead)
-tlist_head  *phead;
+static unsigned long
+resi_sum(tlist_head *phead)
   {
   static char  id[] = "resi_ses";
   ulong   resisize, resisub;
@@ -651,9 +646,8 @@ tlist_head  *phead;
 /*
  * Return TRUE if any process in the session is over limit for memory usage.
  */
-static int overmem_proc(phead, limit)
-tlist_head  *phead;
-unsigned long limit;
+static int
+overmem_proc(tlist_head *phead, unsigned long limit)
   {
   char  *id = "overmem_proc";
   int  fd;
@@ -704,28 +698,14 @@ extern char *msg_momsetlim;
 int
 error(char *string, int value)
   {
-  int  i = 0;
   char  *message;
 
   assert(string != NULL);
   assert(*string != '\0');
-  assert(value > PBSE_);   /* minimum PBS error number */
-  assert(value <= PBSE_NOSYNCMSTR); /* maximum PBS error number */
-  assert(pbs_err_to_txt[i].err_no != 0);
 
-  do
-    {
-    if (pbs_err_to_txt[i].err_no == value)
-      break;
-    }
-  while (pbs_err_to_txt[++i].err_no != 0);
-
-  assert(pbs_err_to_txt[i].err_txt != NULL);
-
-  message = *pbs_err_to_txt[i].err_txt;
+  message = pbse_to_txt(value);
 
   assert(message != NULL);
-
   assert(*message != '\0');
 
   (void)fprintf(stderr, msg_momsetlim, string, message);
@@ -756,9 +736,11 @@ error(char *string, int value)
  * existing limits.  Cannot alter those set by setrlimit (kernel)
  * because we are the wrong process.
  */
-int mom_set_limits(pjob, set_mode)
-job   *pjob;
-int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
+int
+mom_set_limits(
+  job *pjob,
+  int set_mode /* SET_LIMIT_SET or SET_LIMIT_ALTER */
+)
   {
   char  *id = "mom_set_limits";
   char  *pname;
@@ -791,25 +773,31 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
 
     if (strcmp(pname, "cput") == 0)
       {
-      /* cpu time - check, if less than pcput use it */
-      retval = gettime(pres, &value);
+      if (igncput == FALSE)
+        {
+        /* cpu time - check, if less than pcput use it */
+        retval = gettime(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
+        }
       }
     else if (strcmp(pname, "pcput") == 0)
       {
-      /* process cpu time - set */
-      retval = gettime(pres, &value);
+      if (igncput == FALSE)
+        {
+        /* process cpu time - set */
+        retval = gettime(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
 
-      reslim.rlim_cur = reslim.rlim_max =
-                          (unsigned long)((double)value / cputfactor);
+        reslim.rlim_cur = reslim.rlim_max =
+          (unsigned long)((double)value / cputfactor);
 
-      if (setrlimit(RLIMIT_CPU, &reslim) < 0)
-        return (error("RLIMIT_CPU", PBSE_SYSTEM));
+        if (setrlimit(RLIMIT_CPU, &reslim) < 0)
+          return (error("RLIMIT_CPU", PBSE_SYSTEM));
+        }
       }
     else if (strcmp(pname, "file") == 0)   /* set */
       {
@@ -831,43 +819,52 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
       }
     else if (strcmp(pname, "vmem") == 0)   /* check */
       {
-      retval = getsize(pres, &value);
+      if (ignvmem == FALSE)
+        {
+        retval = getsize(pres, &value);
+  
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
-
-      if ((mem_limit == 0) || (value < mem_limit))
-        mem_limit = value;
+        if ((mem_limit == 0) || (value < mem_limit))
+          mem_limit = value;
+        }
       }
     else if (strcmp(pname, "pvmem") == 0)   /* set */
       {
-      retval = getsize(pres, &value);
-
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
-
-      if (value > INT_MAX)
-        return (error(pname, PBSE_BADATVAL));
-
-      if ((mem_limit == 0) || (value < mem_limit))
-        mem_limit = value;
-      }
-    else if (strcmp(pname, "mem") == 0)    /* ignore */
-      {
-      }
-    else if (strcmp(pname, "pmem") == 0)   /* set */
-      {
-      if (set_mode == SET_LIMIT_SET)
+      if (ignvmem == FALSE)
         {
         retval = getsize(pres, &value);
 
         if (retval != PBSE_NONE)
           return (error(pname, retval));
 
-        reslim.rlim_cur = reslim.rlim_max = value;
+        if (value > INT_MAX)
+          return (error(pname, PBSE_BADATVAL));
 
-        if (setrlimit(RLIMIT_RSS, &reslim) < 0)
-          return (error("RLIMIT_RSS", PBSE_SYSTEM));
+        if ((mem_limit == 0) || (value < mem_limit))
+          mem_limit = value;
+        }
+      }
+    else if (strcmp(pname, "mem") == 0)    /* ignore */
+      {
+      }
+    else if (strcmp(pname, "pmem") == 0)   /* set */
+      {
+      if (ignmem == FALSE)
+        {
+        if (set_mode == SET_LIMIT_SET)
+          {
+          retval = getsize(pres, &value);
+
+          if (retval != PBSE_NONE)
+            return (error(pname, retval));
+
+          reslim.rlim_cur = reslim.rlim_max = value;
+ 
+          if (setrlimit(RLIMIT_RSS, &reslim) < 0)
+            return (error("RLIMIT_RSS", PBSE_SYSTEM));
+          }
         }
       }
     else if (strcmp(pname, "walltime") == 0)   /* Check */
@@ -921,8 +918,8 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
  * polling is done using the mom_over_limit machine-dependent function.
  */
 
-int mom_do_poll(pjob)
-job   *pjob;
+int
+mom_do_poll(job *pjob)
   {
   char  *id = "mom_do_poll";
   char  *pname;
@@ -990,8 +987,8 @@ mom_get_sample(void)
  * Otherwise, return FALSE.
  */
 
-int mom_over_limit(pjob)
-job   *pjob;
+int
+mom_over_limit(job *pjob)
   {
   char  *id = "mom_over_limit";
   char  *pname;
@@ -1011,7 +1008,7 @@ job   *pjob;
     assert(pname != NULL);
     assert(*pname != '\0');
 
-    if (strcmp(pname, "cput") == 0)
+    if ((igncput == FALSE) && (strcmp(pname,"cput") == 0))
       {
       retval = gettime(pres, &value);
 
@@ -1026,7 +1023,7 @@ job   *pjob;
         return (TRUE);
         }
       }
-    else if (strcmp(pname, "pcput") == 0)
+    else if ((igncput == FALSE) && (strcmp(pname,"pcput") == 0))
       {
       retval = gettime(pres, &value);
 
@@ -1071,7 +1068,7 @@ job   *pjob;
         return (TRUE);
         }
       }
-    else if (strcmp(pname, "walltime") == 0)
+    else if (ignwalltime == 0 && strcmp(pname, "walltime") == 0)
       {
       if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_HERE) == 0)
         continue;
@@ -1088,9 +1085,7 @@ job   *pjob;
         sprintf(log_buffer,
                 "walltime %d exceeded limit %d",
                 num, value);
-
-        if (ignwalltime == 0)
-          return (TRUE);
+        return (TRUE);
         }
       }
     }
@@ -1105,8 +1100,8 @@ job   *pjob;
  * each resource that can be reported for this machine.  Fill in the
  * correct values.  Return an error code.
  */
-int mom_set_use(pjob)
-job   *pjob;
+int
+mom_set_use(job *pjob)
   {
   char   *id = "mom_set_use";
   resource  *pres;
@@ -1191,10 +1186,8 @@ job   *pjob;
  * Kill a task session.
  * Call with the task pointer and a signal number.
  */
-int kill_task(ptask, sig, pg)
-task *ptask;
-int  sig;
-int         pg;
+int
+kill_task(task *ptask, int sig, int pg)
   {
   char  *id = "kill_task";
   int  ct = 0;
@@ -1267,14 +1260,13 @@ mom_close_poll(void)
   }
 
 /*
- * mom_does_chkpnt - return 1 if mom supports checkpoint
- *       0 if not
+ * mom_does_checkpoint
  */
 
 int
-mom_does_chkpnt(void)
+mom_does_checkpoint(void)
   {
-  return (0);
+  return(CST_NONE);
   }
 
 /*
@@ -1283,10 +1275,8 @@ mom_does_chkpnt(void)
  * If abort is true, kill it too.
  */
 
-int mach_checkpoint(ptask, file, abort)
-task *ptask;
-char *file;
-int  abort;
+int
+mach_checkpoint(task *ptask, char *file, int abort)
   {
   return (-1);
   }
@@ -1297,9 +1287,8 @@ int  abort;
  * Return a -1 on error or sid.
  */
 
-long mach_restart(ptask, file)
-task *ptask;
-char *file;
+long
+mach_restart(task *ptask, char *file)
   {
   return (-1);
   }
