@@ -95,11 +95,11 @@
 #include "server_limits.h"
 #include "attribute.h"
 #include "resource.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "mom_mach.h"
 #include "mom_func.h"
 
-static char ident[] = "@(#) $RCSfile$ $Revision: 2394 $";
+static char ident[] = "@(#) $RCSfile$ $Revision: 2367 $";
 
 /* Global Variables */
 
@@ -139,9 +139,11 @@ open_sgi_proj(void)
  * As a side effect, the access to the project files is closed.
  */
 
-int set_sgi_proj(usern, acct)
-char  *usern;  /* the user name */
-attribute *acct;  /* the account attribute or NULL */
+int
+set_sgi_proj(
+  char *usern,  /* the user name */
+  attribute *acct  /* the account attribute or NULL */
+)
   {
   prid_t    prid;
 
@@ -180,10 +182,8 @@ attribute *acct;  /* the account attribute or NULL */
  *  -2 - if other, message in log_buffer
  */
 
-int set_job(pjob, sjr)
-job *pjob;
-
-struct startjob_rtn *sjr;
+int
+set_job(job *pjob, struct startjob_rtn *sjr)
   {
   extern char noglobid[];
   char  cvtbuf[20];
@@ -212,10 +212,7 @@ struct startjob_rtn *sjr;
 ** Just use "none" since everybody has a different ASH.
 */
 void
-set_globid(pjob, sjr)
-job *pjob;
-
-struct startjob_rtn *sjr;
+set_globid(job *pjob, struct startjob_rtn *sjr)
   {
   extern char noglobid[];
 
@@ -228,18 +225,13 @@ struct startjob_rtn *sjr;
  * set_mach_vars - setup machine dependent environment variables
  */
 int
-set_mach_vars(pjob, vtab)
-job      *pjob;
-
-struct var_table *vtab;
+set_mach_vars(job *pjob, struct var_table *vtab)
   {
   return 0;
   }
 
-char *set_shell(pjob, pwdp)
-job       *pjob;
-
-struct passwd *pwdp;
+char *
+set_shell(job *pjob, struct passwd *pwdp)
   {
   char *cp;
   int   i;
