@@ -97,11 +97,11 @@
 #include "server_limits.h"
 #include "attribute.h"
 #include "resource.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "mom_mach.h"
 #include "mom_func.h"
 
-static char ident[] = "@(#) $RCSfile$ $Revision: 2394 $";
+static char ident[] = "@(#) $RCSfile$ $Revision: 2367 $";
 
 /* Global Variables */
 
@@ -141,9 +141,11 @@ open_sgi_proj(void)
  * As a side effect, the access to the project files is closed.
  */
 
-int set_sgi_proj(usern, acct)
-char  *usern;  /* the user name */
-attribute *acct;  /* the account attribute or NULL */
+int
+set_sgi_proj(
+  char *usern,  /* the user name */
+  attribute *acct  /* the account attribute or NULL */
+)
   {
   prid_t    prid;
 
@@ -179,10 +181,8 @@ attribute *acct;  /* the account attribute or NULL */
  *  -1 - if setsid() fails
  *  -2 - if other, message in log_buffer
  */
-int set_job(pjob, sjr)
-job *pjob;
-
-struct startjob_rtn *sjr;
+int
+set_job(job *pjob, struct startjob_rtn *sjr)
   {
   extern char noglobid[];
   char  cvtbuf[20];
@@ -289,18 +289,13 @@ void set_globid(
  * set_mach_vars - setup machine dependent environment variables
  */
 int
-set_mach_vars(pjob, vtab)
-job      *pjob;
-
-struct var_table *vtab;
+set_mach_vars(job *pjob, struct var_table *vtab)
   {
   return 0;
   }
 
-char *set_shell(pjob, pwdp)
-job       *pjob;
-
-struct passwd *pwdp;
+char *
+set_shell(job *pjob, struct passwd *pwdp)
   {
   char *cp;
   int   i;
