@@ -118,7 +118,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <netdb.h>
-#include <pthread.h>
 
 #include "pbs_ifl.h"
 #include "list_link.h"
@@ -611,7 +610,7 @@ static void job_init_wattr(
 
 
 /*
- * job_purge_thread - purge job from system
+ * job_purge - purge job from system
  *
  * The job is dequeued; the job control file, script file and any spooled
  * output files are unlinked, and the job structure is freed.
@@ -619,16 +618,62 @@ static void job_init_wattr(
  * removed.
  */
 
-void *job_purge_thread(void *jobtopurge)
+void job_purge(
+
+  job *pjob)  /* I (modified) */
+
   {
-  static char   id[] = "job_purge_thread";
-  job *pjob;
+  static char   id[] = "job_purge";
+
   char          namebuf[MAXPATHLEN + 1];
   extern char  *msg_err_purgejob;
   int           rc;
+  int           pid;
+
   extern void MOMCheckRestart A_((void));
 
-  pjob = (job *)jobtopurge;
+  pid = fork();
+  if(pid < 0)
+    {
+    sprintf(log_buffer, "fork() failed in job_purge: %d", errno);
+    log_record(
+      PBSEVENT_DEBUG,
+      PBS_EVENTCLASS_JOB,
+      pjob->ji_qs.ji_jobid,
+      log_buffer);
+
+    return;
+    }
+
+  if(pid != 0)
+    {
+    /* we are the parent.*/
+    delete_link(&pjob->ji_jobque);
+
+    delete_link(&pjob->ji_alljobs);
+
+    if (LOGLEVEL >= 6)
+      {
+      sprintf(log_buffer,"removing job");
+
+      log_record(
+        PBSEVENT_DEBUG,
+        PBS_EVENTCLASS_JOB,
+        pjob->ji_qs.ji_jobid,
+        log_buffer);
+      }
+    job_free(pjob);
+
+    /* if no jobs are left, check if MOM should be restarted */
+
+    if (((job *)GET_NEXT(svr_alljobs)) == NULL)
+      MOMCheckRestart();
+
+    return;
+    }
+
+
+  /* This is the child */
 
   if (pjob->ji_flags & MOM_HAS_TMPDIR)
     {
@@ -648,7 +693,7 @@ void *job_purge_thread(void *jobtopurge)
         {
         /* FAILURE */
 
-        pthread_exit(NULL);
+        _exit(1);
         }
 
       rc = remtree(namebuf);
@@ -698,21 +743,6 @@ void *job_purge_thread(void *jobtopurge)
     pjob->ji_flags &= ~MOM_HAS_NODEFILE;
     }
 
-  delete_link(&pjob->ji_jobque);
-
-  delete_link(&pjob->ji_alljobs);
-
-  if (LOGLEVEL >= 6)
-    {
-    sprintf(log_buffer,"removing job");
-
-    log_record(
-      PBSEVENT_DEBUG,
-      PBS_EVENTCLASS_JOB,
-      pjob->ji_qs.ji_jobid,
-      log_buffer);
-    }
-
   strcpy(namebuf,path_jobs); /* delete script file */
 
   strcat(namebuf,pjob->ji_qs.ji_fileprefix);
@@ -771,58 +801,8 @@ void *job_purge_thread(void *jobtopurge)
       log_buffer);
     }
 
-  job_free(pjob);
-
-  /* if no jobs are left, check if MOM should be restarted */
-
-  if (((job *)GET_NEXT(svr_alljobs)) == NULL)
-    MOMCheckRestart();
-
-  pthread_exit(NULL);
-  }
-
-void job_purge(
-
-  job *pjob)  /* I (modified) */
-
-  {
-  static char   id[] = "job_purge";
-  pthread_attr_t attr;
-  pthread_t *thread;
-  int rc;
-
-  rc = pthread_attr_init( &attr );
-  if(rc)
-    {
-    sprintf(log_buffer, "pthread_attr_init failded. job number %s", pjob->ji_qs.ji_jobid);
-    log_err(rc, id, log_buffer);
-    return;
-    }
-
-  rc = pthread_attr_setdetachstate(
-     &attr, PTHREAD_CREATE_DETACHED );
-  if(rc)
-    {
-    sprintf(log_buffer, "pthread_attr_setdetachstate failded. job number %s", pjob->ji_qs.ji_jobid);
-    log_err(rc, id, log_buffer);
-    return;
-    }
-  thread = (pthread_t *)malloc(sizeof(pthread_t));
-  if(thread == NULL) 
-    {
-    sprintf(log_buffer, "Could not allocate memory for job_purge thread");
-    log_err(errno, id, log_buffer);
-    return;
-    }
-
-  rc = pthread_create(thread, &attr, &job_purge_thread, pjob);
-  if(rc)
-    {
-    sprintf(log_buffer, "pthread_create failed: %d", rc);
-    log_err(rc, id, log_buffer);
-    }
-
-  return;
+  /* use _exit so we do not run any of the at_exit or on_exit routines */
+  _exit(0);
   }  /* END job_purge() */
 
 
