@@ -2286,6 +2286,8 @@ void check_state(
 
   static char tmpPBSNodeMsgBuf[1024];
 
+  char *id = "check_state";
+
   if (Force)
     {
     ICount = 0;
@@ -2378,7 +2380,21 @@ void check_state(
                 proper action may be context sensitive */
 
       if (IsError == 1)
+        {
         internal_state |= INUSE_DOWN;
+
+        snprintf(log_buffer,sizeof(log_buffer),
+          "Setting node to down. The node health script output the following message:\n%s\n",
+          tmpPBSNodeMsgBuf);
+        log_event(PBSEVENT_SYSTEM,PBS_EVENTCLASS_NODE,id,log_buffer);
+        }
+      else
+        {
+        snprintf(log_buffer,sizeof(log_buffer),
+          "Node health script ran and says the node is healthy with this message:\n%s\n",
+          tmpPBSNodeMsgBuf);
+        log_event(PBSEVENT_SYSTEM,PBS_EVENTCLASS_NODE,id,log_buffer);
+        }
       }
     }      /* END if (PBSNodeCheckPath[0] != '\0') */
 
