@@ -240,10 +240,9 @@ int main(
 
   if (routem == NULL)
     {
-    fprintf(stderr, "%s: malloc failed\n",
-      argv[0]);
+    perror("cannot alloc memory");
 
-    exit(1);
+    exit(5);
     }
 
   for (i = 0;i < maxfd;++i)
@@ -256,10 +255,10 @@ int main(
   routem[main_sock_err].r_where = new_err;
 
   FD_ZERO(&readset);
-  FD_SET(main_sock_out,&readset);
-  FD_SET(main_sock_err,&readset);
+  FD_SET(main_sock_out, &readset);
+  FD_SET(main_sock_err, &readset);
 
-  if (listen(main_sock_out,TORQUE_LISTENQUEUE) < 0)
+  if (listen(main_sock_out, TORQUE_LISTENQUEUE) < 0)
     {
     perror("listen on out");
 
@@ -279,7 +278,7 @@ int main(
     timeout.tv_usec = 0;
     timeout.tv_sec  = 10;
 
-    n = select(FD_SETSIZE,&selset,(fd_set *)0,(fd_set *)0,&timeout);
+    n = select(FD_SETSIZE, &selset, (fd_set *)0, (fd_set *)0, &timeout);
 
     if (n == -1)
       {
@@ -302,7 +301,7 @@ int main(
       if (getppid() != parent)
         {
 #ifdef DEBUG
-        fprintf(stderr, "%s: Parent has gone, and so do I\n",
+        fprintf(stderr, "%s: Parent has gone, and so will I\n",
                 argv[0]);
 #endif /* DEBUG */
 
