@@ -118,7 +118,7 @@
 #include "server_limits.h"
 #include "attribute.h"
 #include "resource.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "log.h"
 #include "mom_mach.h"
 #include "resmon.h"
@@ -167,7 +167,9 @@ extern double cputfactor;
 extern double wallfactor;
 extern  long    system_ncpus;
 extern  int     ignwalltime;
+extern  int     igncput;
 extern  int     ignvmem;
+extern  int     ignmem;
 
 /*
 ** local functions and data
@@ -196,7 +198,6 @@ pbs_plinks     *Proc_lnks = NULL; /* process links table head */
 
 #define TBL_INC 50
 
-extern struct pbs_err_to_txt pbs_err_to_txt[];
 extern time_t   time_now;
 
 extern char extra_parm[];
@@ -268,9 +269,8 @@ dep_cleanup(void)
  *  sizeof(word) = sizeof(int)
  */
 
-static int local_getsize(pres, ret)
-resource  *pres;
-unsigned long *ret;
+static int
+local_getsize(resource *pres, unsigned long *ret)
   {
   unsigned long value;
 
@@ -305,9 +305,8 @@ unsigned long *ret;
  * decoded value of time in seconds in the unsigned long integer.
  */
 
-static int local_gettime(pres, ret)
-resource  *pres;
-unsigned long *ret;
+static int
+local_gettime(resource *pres, unsigned long *ret)
   {
 
   if (pres->rs_value.at_type != ATR_TYPE_LONG)
@@ -357,8 +356,8 @@ pid_t sid;
  * consumed for all tasks executed by the job, in seconds.
  * The "real" time is adjusted by "cputfactor"
  */
-static unsigned long cput_sum(pjob)
-job   *pjob;
+static unsigned long
+cput_sum(job *pjob)
   {
   char   *id = "cput_sum";
   ulong    cputime, addtime;
@@ -406,9 +405,8 @@ job   *pjob;
  * Return TRUE if any process in the job is over limit for cputime usage
  * adjusted by cputfactor.
  */
-static int overcput_proc(pjob, limit)
-job   *pjob;
-unsigned long limit;
+static int
+overcput_proc(job *pjob, unsigned long limit)
   {
   char  *id = "overcput_proc";
   ulong  cputime;
@@ -438,8 +436,8 @@ unsigned long limit;
  * Returns the total number of bytes of address
  * space consumed by all current tasks within the session.
  */
-static unsigned long mem_sum(pjob)
-job   *pjob;
+static unsigned long
+mem_sum(job *pjob)
   {
   char  *id = "mem_sum";
   ulong  memsize;
@@ -466,8 +464,8 @@ job   *pjob;
 /*
  * Internal session mem (workingset) size function.
  */
-static unsigned long resi_sum(pjob)
-job   *pjob;
+static unsigned long
+resi_sum(job *pjob)
   {
   char  *id = "resi_sum";
   ulong  resisize;
@@ -497,28 +495,14 @@ extern char *msg_momsetlim;
 int
 error(char *string, int value)
   {
-  int  i = 0;
   char  *message;
 
   assert(string != NULL);
   assert(*string != '\0');
-  assert(value > PBSE_);   /* minimum PBS error number */
-  assert(value <= PBSE_NOSYNCMSTR); /* maximum PBS error number */
-  assert(pbs_err_to_txt[i].err_no != 0);
 
-  do
-    {
-    if (pbs_err_to_txt[i].err_no == value)
-      break;
-    }
-  while (pbs_err_to_txt[++i].err_no != 0);
-
-  assert(pbs_err_to_txt[i].err_txt != NULL);
-
-  message = *pbs_err_to_txt[i].err_txt;
+  message = pbse_to_txt(value);
 
   assert(message != NULL);
-
   assert(*message != '\0');
 
   (void)fprintf(stderr, msg_momsetlim, string, message);
@@ -549,9 +533,11 @@ error(char *string, int value)
  * existing limits.  Cannot alter those set by setrlimit (kernel)
  * because we are the wrong process.
  */
-int mom_set_limits(pjob, set_mode)
-job   *pjob;
-int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
+int
+mom_set_limits(
+  job *pjob,
+  int set_mode /* SET_LIMIT_SET or SET_LIMIT_ALTER */
+)
   {
   char  *id = "mom_set_limits";
   char  *pname;
@@ -584,24 +570,30 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
 
     if (strcmp(pname, "cput") == 0)   /* cpu time - check */
       {
-      retval = local_gettime(pres, &value);
+      if (igncput == FALSE)
+        {
+        retval = local_gettime(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
+        }
       }
     else if (strcmp(pname, "pcput") == 0)
       {
-      /* process cpu time - set */
-      retval = local_gettime(pres, &value);
+      if (igncput == FALSE)
+        {
+        /* process cpu time - set */
+        retval = local_gettime(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
 
-      reslim.rlim_cur = reslim.rlim_max =
-                          (unsigned long)((double)value / cputfactor);
+        reslim.rlim_cur = reslim.rlim_max =
+          (unsigned long)((double)value / cputfactor);
 
-      if (setrlimit(RLIMIT_CPU, &reslim) < 0)
-        return (error("RLIMIT_CPU", PBSE_SYSTEM));
+        if (setrlimit(RLIMIT_CPU, &reslim) < 0)
+          return (error("RLIMIT_CPU", PBSE_SYSTEM));
+        }
       }
     else if (strcmp(pname, "file") == 0)   /* set */
       {
@@ -621,16 +613,56 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
           return (error(pname, PBSE_SYSTEM));
         }
       }
-    else if (strcmp(pname, "mem") == 0)    /* check */
+    else if (strcmp(pname, "mem") == 0)   /* check */
       {
-      retval = local_getsize(pres, &value);
+      if (ignmem == FALSE)
+        {
+        retval = local_getsize(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
+        }
       }
     else if (strcmp(pname, "pmem") == 0)   /* set */
       {
-      if (set_mode == SET_LIMIT_SET)
+      if (ignmem == FALSE)
+        {
+        if (set_mode == SET_LIMIT_SET)
+          {
+          retval = local_getsize(pres, &value);
+
+          if (retval != PBSE_NONE)
+            return (error(pname, retval));
+
+          if (value > LONG_MAX)
+            return (error(pname, PBSE_BADATVAL));
+
+          reslim.rlim_cur = reslim.rlim_max = value;
+
+          if (setrlimit(RLIMIT_DATA, &reslim) < 0)
+            return (error("RLIMIT_DATA", PBSE_SYSTEM));
+
+          if (setrlimit(RLIMIT_STACK, &reslim) < 0)
+            return (error("RLIMIT_STACK", PBSE_SYSTEM));
+          }
+        }
+      }
+    else if (strcmp(pname, "vmem") == 0)   /* check */
+      {
+      if (ignvmem == FALSE)
+        {
+        retval = local_getsize(pres, &value);
+
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
+
+        if ((mem_limit == 0) || (value < mem_limit))
+          mem_limit = value;
+        }
+      }
+    else if (strcmp(pname, "pvmem") == 0)   /* set */
+      {
+      if (ignvmem == FALSE)
         {
         retval = local_getsize(pres, &value);
 
@@ -640,38 +672,10 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
         if (value > LONG_MAX)
           return (error(pname, PBSE_BADATVAL));
 
-        reslim.rlim_cur = reslim.rlim_max = value;
-
-        if (setrlimit(RLIMIT_DATA, &reslim) < 0)
-          return (error("RLIMIT_DATA", PBSE_SYSTEM));
-
-        if (setrlimit(RLIMIT_STACK, &reslim) < 0)
-          return (error("RLIMIT_STACK", PBSE_SYSTEM));
+        if ((mem_limit == 0) || (value < mem_limit))
+          mem_limit = value;
         }
       }
-    else if (strcmp(pname, "vmem") == 0)   /* check */
-      {
-      retval = local_getsize(pres, &value);
-
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
-
-      if ((mem_limit == 0) || (value < mem_limit))
-        mem_limit = value;
-      }
-    else if (strcmp(pname, "pvmem") == 0)   /* set */
-      {
-      retval = local_getsize(pres, &value);
-
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
-
-      if (value > LONG_MAX)
-        return (error(pname, PBSE_BADATVAL));
-
-      if ((mem_limit == 0) || (value < mem_limit))
-        mem_limit = value;
-      }
     else if (strcmp(pname, "walltime") == 0)   /* Check */
       {
       retval = local_gettime(pres, &value);
@@ -720,8 +724,8 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
  * polling is done using the mom_over_limit machine-dependent function.
  */
 
-int mom_do_poll(pjob)
-job   *pjob;
+int
+mom_do_poll(job *pjob)
   {
   char  *id = "mom_do_poll";
   char  *pname;
@@ -837,8 +841,8 @@ mom_get_sample(void)
  * Otherwise, return FALSE.
  */
 
-int mom_over_limit(pjob)
-job   *pjob;
+int
+mom_over_limit(job *pjob)
   {
   char  *id = "mom_over_limit";
   char  *pname;
@@ -860,7 +864,7 @@ job   *pjob;
     assert(pname != NULL);
     assert(*pname != '\0');
 
-    if (strcmp(pname, "cput") == 0)
+    if ((igncput == FALSE) && (strcmp(pname, "cput") == 0))
       {
       retval = local_gettime(pres, &value);
 
@@ -875,7 +879,7 @@ job   *pjob;
         return (TRUE);
         }
       }
-    else if (strcmp(pname, "pcput") == 0)
+    else if ((igncput == FALSE) && (strcmp(pname, "pcput") == 0))
       {
       retval = local_gettime(pres, &value);
 
@@ -905,7 +909,7 @@ job   *pjob;
         return (TRUE);
         }
       }
-    else if (strcmp(pname, "walltime") == 0)
+    else if (ignwalltime == 0 && strcmp(pname, "walltime") == 0)
       {
       if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_HERE) == 0)
         continue;
@@ -922,9 +926,7 @@ job   *pjob;
         sprintf(log_buffer,
                 "walltime %ld exceeded limit %ld",
                 num, value);
-
-        if (ignwalltime == 0)
-          return (TRUE);
+        return (TRUE);
         }
       }
     }
@@ -941,8 +943,8 @@ job   *pjob;
  *
  * Assumes that the session ID attribute has already been set.
  */
-int mom_set_use(pjob)
-job   *pjob;
+int
+mom_set_use(job *pjob)
   {
   char   *id = "mom_set_use";
   resource  *pres;
@@ -1150,10 +1152,8 @@ static void kill_ptree(int idx, int flag, int sig)
  * Kill a task session.
  * Call with the task pointer and a signal number.
  */
-int kill_task(ptask, sig, pg)
-task *ptask;
-int   sig;
-int         pg;
+int
+kill_task(task *ptask, int sig, int pg)
   {
   char  *id = "kill_task";
   int  ct = 0;
@@ -1209,14 +1209,13 @@ mom_close_poll(void)
   }
 
 /*
- * mom_does_chkpnt - return 1 if mom supports checkpoint
- *       0 if not
+ * mom_does_checkpoint
  */
 
 int
-mom_does_chkpnt(void)
+mom_does_checkpoint(void)
   {
-  return (0);
+  return(CST_NONE);
   }
 
 /*
@@ -1225,10 +1224,8 @@ mom_does_chkpnt(void)
  * If abort is true, kill it too.
  */
 
-int mach_checkpoint(ptask, file, abort)
-task *ptask;
-char *file;
-int  abort;
+int
+mach_checkpoint(task *ptask, char *file, int abort)
   {
   return (-1);
   }
@@ -1239,9 +1236,8 @@ int  abort;
  * Return -1 on error or sid if okay.
  */
 
-long mach_restart(ptask, file)
-task *ptask;
-char *file;
+long
+mach_restart(task *ptask, char *file)
   {
   return (-1);
   }
