@@ -1132,10 +1132,13 @@ int main(
 
     lock_out(lockfds, F_WRLCK);
 
-    if (!freopen(dbfile, "a", stdout)) {
-      perror("lockout, attempting to freopen dbfile");
+    if (freopen(dbfile, "a", stdout) == NULL)
+      {
+      perror("opening lockfile");
+
       exit(1);
-    }
+      }
+
 
     setvbuf(stdout, NULL, _IOLBF, 0);
 
@@ -1149,10 +1152,12 @@ int main(
     pid = getpid();
     }
 
-  if (!freopen("/dev/null", "r", stdin)) {
-    perror("lockout, attempting to freopen /dev/null");
+  if (freopen("/dev/null", "r", stdin) == NULL)
+    {
+    perror("opening /dev/null");
+
     exit(1);
-  }
+    }
 
   /* write scheduler's pid into lockfile */
 
