@@ -134,7 +134,7 @@ int dis_request_read(
 
   /* Decode the Request Header, that will tell the request type */
 
-  if ((rc = tcp_decode_DIS_ReqHdr(sfds, request, &proto_type, &proto_ver)))
+  if ((rc = decode_DIS_ReqHdr(sfds, request, &proto_type, &proto_ver)))
     {
     if (rc == DIS_EOF)
       {
@@ -206,13 +206,13 @@ int dis_request_read(
 
       CLEAR_HEAD(request->rq_ind.rq_queuejob.rq_attr);
 
-      rc = tcp_decode_DIS_QueueJob(sfds, request);
+      rc = decode_DIS_QueueJob(sfds, request);
 
       break;
 
     case PBS_BATCH_JobCred:
 
-      rc = tcp_decode_DIS_JobCred(sfds, request);
+      rc = decode_DIS_JobCred(sfds, request);
 
       break;
 
@@ -220,7 +220,7 @@ int dis_request_read(
 
     case PBS_BATCH_MvJobFile:
 
-      rc = tcp_decode_DIS_JobFile(sfds, request);
+      rc = decode_DIS_JobFile(sfds, request);
 
       break;
 
@@ -230,7 +230,7 @@ int dis_request_read(
 
     case PBS_BATCH_Rerun:
 
-      rc = tcp_decode_DIS_JobId(sfds, request->rq_ind.rq_commit);
+      rc = decode_DIS_JobId(sfds, request->rq_ind.rq_commit);
 
       break;
 
@@ -244,31 +244,31 @@ int dis_request_read(
 
     case PBS_BATCH_AsyModifyJob:
 
-      rc = tcp_decode_DIS_Manage(sfds, request);
+      rc = decode_DIS_Manage(sfds, request);
 
       break;
 
     case PBS_BATCH_MessJob:
 
-      rc = tcp_decode_DIS_MessageJob(sfds, request);
+      rc = decode_DIS_MessageJob(sfds, request);
 
       break;
 
     case PBS_BATCH_Shutdown:
 
-      rc = tcp_decode_DIS_ShutDown(sfds, request);
+      rc = decode_DIS_ShutDown(sfds, request);
 
       break;
 
     case PBS_BATCH_SignalJob:
 
-      rc = tcp_decode_DIS_SignalJob(sfds, request);
+      rc = decode_DIS_SignalJob(sfds, request);
 
       break;
 
     case PBS_BATCH_StatusJob:
 
-      rc = tcp_decode_DIS_Status(sfds, request);
+      rc = decode_DIS_Status(sfds, request);
 
       break;
 
@@ -276,7 +276,7 @@ int dis_request_read(
 
     case PBS_BATCH_LocateJob:
 
-      rc = tcp_decode_DIS_JobId(sfds, request->rq_ind.rq_locate);
+      rc = decode_DIS_JobId(sfds, request->rq_ind.rq_locate);
 
       break;
 
@@ -284,7 +284,7 @@ int dis_request_read(
 
     case PBS_BATCH_ReleaseJob:
 
-      rc = tcp_decode_DIS_Manage(sfds, request);
+      rc = decode_DIS_Manage(sfds, request);
 
       break;
 
@@ -292,7 +292,7 @@ int dis_request_read(
 
     case PBS_BATCH_OrderJob:
 
-      rc = tcp_decode_DIS_MoveJob(sfds, request);
+      rc = decode_DIS_MoveJob(sfds, request);
 
       break;
 
@@ -302,7 +302,7 @@ int dis_request_read(
 
     case PBS_BATCH_StageIn:
 
-      rc = tcp_decode_DIS_RunJob(sfds, request);
+      rc = decode_DIS_RunJob(sfds, request);
 
       break;
 
@@ -312,7 +312,7 @@ int dis_request_read(
 
       CLEAR_HEAD(request->rq_ind.rq_select);
 
-      rc = tcp_decode_DIS_svrattrl(sfds, &request->rq_ind.rq_select);
+      rc = decode_DIS_svrattrl(sfds, &request->rq_ind.rq_select);
 
       break;
 
@@ -323,13 +323,13 @@ int dis_request_read(
     case PBS_BATCH_StatusSvr:
       /* DIAGTODO: add PBS_BATCH_StatusDiag */
 
-      rc = tcp_decode_DIS_Status(sfds, request);
+      rc = decode_DIS_Status(sfds, request);
 
       break;
 
     case PBS_BATCH_TrackJob:
 
-      rc = tcp_decode_DIS_TrackJob(sfds, request);
+      rc = decode_DIS_TrackJob(sfds, request);
 
       break;
 
@@ -339,25 +339,25 @@ int dis_request_read(
 
     case PBS_BATCH_ReleaseResc:
 
-      rc = tcp_decode_DIS_Rescl(sfds, request);
+      rc = decode_DIS_Rescl(sfds, request);
 
       break;
 
     case PBS_BATCH_RegistDep:
 
-      rc = tcp_decode_DIS_Register(sfds, request);
+      rc = decode_DIS_Register(sfds, request);
 
       break;
 
     case PBS_BATCH_AuthenUser:
 
-      rc = tcp_decode_DIS_Authen(sfds, request);
+      rc = decode_DIS_Authen(sfds, request);
 
       break;
 
     case PBS_BATCH_JobObit:
 
-      rc = tcp_decode_DIS_JobObit(sfds, request);
+      rc = decode_DIS_JobObit(sfds, request);
 
       break;
 
@@ -366,7 +366,7 @@ int dis_request_read(
       /* pbs_mom services */
 
     case PBS_BATCH_ReturnFiles:
-      rc = tcp_decode_DIS_ReturnFiles(sfds, request);
+      rc = decode_DIS_ReturnFiles(sfds, request);
 
       break;
 
@@ -374,7 +374,7 @@ int dis_request_read(
 
     case PBS_BATCH_DelFiles:
 
-      rc = tcp_decode_DIS_CopyFiles(sfds, request);
+      rc = decode_DIS_CopyFiles(sfds, request);
 
       break;
 
@@ -402,7 +402,7 @@ int dis_request_read(
     {
     /* Decode the Request Extension, if present */
 
-    if ((rc = tcp_decode_DIS_ReqExtend(sfds, request)))
+    if ((rc = decode_DIS_ReqExtend(sfds, request)))
       {
       sprintf(log_buffer, "req extension bad, dis error %d (%s), type=%s",
               rc,
@@ -454,7 +454,7 @@ int DIS_reply_read(
   {
   DIS_tcp_setup(sock);
 
-  return(tcp_decode_DIS_replySvr(sock, preply));
+  return(decode_DIS_replySvr(sock, preply));
   }
 
 /* END dis_read.c */
