@@ -102,7 +102,7 @@
 #include "server_limits.h"
 #include "list_link.h"
 #include "attribute.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "log.h"
 #include "svrfunc.h"
 #include "server.h"
@@ -126,7 +126,7 @@ int save_tmsock(job *);
 int recov_tmsock(int, job *);
 #endif
 
-extern int job_qs_upgrade(job *, int , int);
+extern int job_qs_upgrade(job *, int, char *, int);
 
 /* global data items */
 
@@ -450,11 +450,11 @@ job *job_recov(
     {
     /* ji_qs is older version */
     sprintf(log_buffer,
-            "%s appears to be from a different version. Attempting to convert.\n",
+            "%s appears to be from an old version. Attempting to convert.\n",
             namebuf);
     log_err(-1, "job_recov", log_buffer);
 
-    if (job_qs_upgrade(pj, fds, pj->ji_qs.qs_version) != 0)
+    if (job_qs_upgrade(pj, fds, namebuf, pj->ji_qs.qs_version) != 0)
       {
       sprintf(log_buffer, "unable to upgrade %s\n", namebuf);
 
@@ -568,7 +568,7 @@ job *job_recov(
 
   if (qs_upgrade == TRUE)
     {
-    job_save(pj, 1);
+    job_save(pj, SAVEJOB_FULL);
     }
 
   return(pj);
