@@ -107,7 +107,7 @@
 #include "batch_request.h"
 #include "work_task.h"
 #include "svrfunc.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "log.h"
 #include "pbs_nodes.h"
 #include "rpp.h"
@@ -115,6 +115,9 @@
 #include "dis_init.h"
 #include "resmon.h"
 #include "mcom.h"
+#include "utils.h"
+
+#define IS_VALID_STR(STR)  (((STR) != NULL) && ((STR)[0] != '\0'))
 
 extern void DIS_rpp_reset A_((void));
 
@@ -165,10 +168,18 @@ extern int            SvrNodeCt;
 #define SKIP_ANYINUSE 2
 #define SKIP_NONE_REUSE 3
 
+#ifndef MAX_BM
+#define MAX_BM   64
+#endif
+
 int hasprop(struct pbsnode *, struct prop *);
 void send_cluster_addrs(struct work_task *);
 int add_cluster_addrs(int);
 int is_compose(int, int);
+int add_job_to_node(struct pbsnode *,struct pbssubn *,short,job *,int);
+int node_satisfies_request(struct pbsnode *,char *);
+int reserve_node(struct pbsnode *,short,job *,char *,struct howl **);
+int build_host_list(struct howl **,struct pbssubn *,struct pbsnode *);
 
 /*
 
@@ -199,19 +210,7 @@ funcs_dis(void)  /* The equivalent of DIS_tcp_funcs() */
 /*#define      close_dis(x)    rpp_close(x) */
 /*#define      flush_dis(x)    rpp_flush(x) */
 
-/*
- * Tree search generalized from Knuth (6.2.2) Algorithm T just like
- * the AT&T man page says.
- *
- * The tree_t structure is for internal use only, lint doesn't grok it.
- *
- * Written by reading the System V Interface Definition, not the code.
- *
- * Totally public domain.
- */
-/*LINTLIBRARY*/
-
-/*
+/**
 **      Modified by Tom Proett <proett@nas.nasa.gov> for PBS.
 */
 
@@ -219,42 +218,11 @@ tree *ipaddrs = NULL; /* tree of ip addrs */
 tree *streams = NULL; /* tree of stream numbers */
 
 
-
-/* find value in tree, return NULL if not found */
-
-struct pbsnode *tfind(
-
-        const u_long   key, /* I - key to be located */
-        tree         **rootp) /* O - address of tree root */
-
-  {
-  if (rootp == NULL)
-    {
-    return(NULL);
-    }
-
-  while (*rootp != NULL)
-    {
-    /* Knuth's T1: */
-
-    if (key == (*rootp)->key) /* T2: */
-      {
-      return((*rootp)->nodep); /* we found it! */
-      }
-
-    rootp = (key < (*rootp)->key) ?
-
-            &(*rootp)->left : /* T3: follow left branch */
-            &(*rootp)->right; /* T4: follow right branch */
-    }
-
-  return(NULL);
-  }  /* END tfind() */
-
-
-
-
-
+/**
+ * specialized version of tfind for looking in the ipadders tree
+ * @param key - the node we are searching for
+ * @return a pointer to the pbsnode
+*/
 
 struct pbsnode *tfind_addr(
 
@@ -266,175 +234,6 @@ struct pbsnode *tfind_addr(
 
 
 
-
-
-void tinsert(
-
-  const u_long     key,  /* key to be located */
-  struct pbsnode  *nodep,
-  tree           **rootp) /* address of tree root */
-
-  {
-  register tree *q;
-
-  if (nodep != NULL)
-    {
-    /*
-    DBPRT(("tinsert: %lu %s stream %d\n",
-      key,
-      nodep->nd_name,
-      nodep->nd_stream))
-    */
-    }
-
-  if (rootp == NULL)
-    {
-    return;
-    }
-
-  while (*rootp != NULL)
-    {
-    /* Knuth's T1: */
-
-    if (key == (*rootp)->key) /* T2: */
-      {
-      return;   /* we found it! */
-      }
-
-    rootp = (key < (*rootp)->key) ?
-
-            &(*rootp)->left : /* T3: follow left branch */
-            &(*rootp)->right; /* T4: follow right branch */
-    }
-
-  q = (tree *) malloc(sizeof(tree)); /* T5: key not found */
-
-  if (q != NULL)
-    {
-    /* make new node */
-    *rootp = q;   /* link new node to old */
-    q->key = key;   /* initialize new node */
-    q->nodep = nodep;
-    q->left = q->right = NULL;
-    }
-
-  return;
-  }  /* END tinsert() */
-
-
-
-
-/* delete node with given key */
-
-void *tdelete(
-
-  const u_long   key, /* key to be deleted */
-  tree         **rootp) /* address of the root of tree */
-
-  {
-  tree  *p;
-  register tree *q;
-  register tree *r;
-
-  if (LOGLEVEL >= 6)
-    {
-    sprintf(log_buffer, "deleting key %lu",
-            key);
-
-    log_record(
-      PBSEVENT_SCHED,
-      PBS_EVENTCLASS_REQUEST,
-      "tdelete",
-      log_buffer);
-    }
-
-  if ((rootp == NULL) || ((p = *rootp) == NULL))
-    {
-    return(NULL);
-    }
-
-  while (key != (*rootp)->key)
-    {
-    p = *rootp;
-
-    rootp = (key < (*rootp)->key) ?
-            &(*rootp)->left :  /* left branch */
-            &(*rootp)->right;  /* right branch */
-
-    if (*rootp == NULL)
-      {
-      return(NULL);  /* key not found */
-      }
-    }
-
-  r = (*rootp)->right;    /* D1: */
-
-  if ((q = (*rootp)->left) == NULL)  /* Left */
-    {
-    q = r;
-    }
-  else if (r != NULL)
-    {
-    /* Right is null? */
-
-    if (r->left == NULL)
-      {
-      /* D2: Find successor */
-      r->left = q;
-
-      q = r;
-      }
-    else
-      {
-      /* D3: Find (struct tree_t *)0 link */
-
-      for (q = r->left;q->left != NULL;q = r->left)
-        {
-        r = q;
-        }
-
-      r->left = q->right;
-
-      q->left = (*rootp)->left;
-      q->right = (*rootp)->right;
-      }
-    }
-
-  free((struct tree_t *)*rootp);     /* D4: Free node */
-
-  *rootp = q;                         /* link parent to new node */
-
-  return(p);
-  }  /* END tdelete() */
-
-
-
-
-void tfree(
-
-  tree **rootp)
-
-  {
-  if (rootp == NULL || *rootp == NULL)
-    {
-    return;
-    }
-
-  tfree(&(*rootp)->left);
-
-  tfree(&(*rootp)->right);
-
-  free(*rootp);
-
-  *rootp = NULL;
-
-  return;
-  }  /* END tfree() */
-
-
-
-
-
 /* update_node_state - central location for updating node state */
 /* NOTE:  called each time a node is marked down, each time a MOM reports node  */
 /*        status, and when pbs_server sends hello/cluster_addrs */
@@ -862,9 +661,12 @@ job *find_job_by_node(
 
 
 
-
 /*
  * sync_node_jobs() - determine if a MOM has a stale job and possibly delete it
+ *
+ * This function is called every time we get a node stat from the pbs_mom.
+ *
+ * @see is_stat_get()
  */
 
 void sync_node_jobs(
@@ -913,7 +715,7 @@ void sync_node_jobs(
     return;
     }
 
-  jobidstr = strtok(joblist," ");
+  jobidstr = strtok(joblist, " ");
 
   while ((jobidstr != NULL) && isdigit(*jobidstr))
     {
@@ -929,6 +731,7 @@ void sync_node_jobs(
 
           /* double check the job struct because we could be in the middle of moving
              the job around because of data staging, suspend, or rerun */
+
           if (pjob->ji_wattr[(int)JOB_ATR_exec_host].at_val.at_str == NULL)
             {
             pjob = NULL;
@@ -943,7 +746,7 @@ void sync_node_jobs(
           {
           /* job is reported by mom but server has no record of job */
 
-          sprintf(log_buffer,"stray job %s found on %s",
+          sprintf(log_buffer, "stray job %s found on %s",
             jobidstr,
             np->nd_name);
 
@@ -970,10 +773,9 @@ void sync_node_jobs(
               {
               strcpy(preq->rq_ind.rq_delete.rq_objname, jobidstr);
 
-              if (issue_Drequest(conn,preq,release_req,0) != 0)
+              if (issue_Drequest(conn, preq, release_req, 0) != 0)
                 {
                 /* release_req will free preq and close connection if successful */
-
                 free_br(preq);
 
                 svr_disconnect(conn);
@@ -999,6 +801,124 @@ void sync_node_jobs(
 
 
 
+/*
+ * update_job_data() - update job with values passed through "jobdata"
+ *
+ * This function is called every time we get a "jobdata" status from the pbs_mom.
+ *
+ * @see is_stat_get()
+ */
+
+void update_job_data(
+
+  struct pbsnode *np,            /* I */
+  char           *jobstring_in)  /* I (changed attributes sent by mom) */
+
+  {
+  char      *id = "update_job_data";
+
+  char      *jobdata;
+  char      *jobidstr;
+  char      *attr_name;
+  char      *attr_value;
+  
+
+  struct job *pjob;
+
+  if ((jobstring_in == NULL) || (!isdigit(*jobstring_in)))
+    {
+    /* NO-OP */
+
+    return;
+    }
+
+  if (np->nd_state & INUSE_DELETED)
+    {
+    /* should never happen */
+
+    return;
+    }
+
+  /* FORMAT <JOBID>:<atrtributename=value>,<atrtributename=value>... */
+
+  jobdata = strdup(jobstring_in);
+
+  jobidstr = strtok(jobdata, ":");
+
+  if ((jobidstr != NULL) && isdigit(*jobidstr))
+    {
+    if (strstr(jobidstr, server_name) != NULL)
+      {
+      pjob = find_job_by_node(np, jobidstr);
+      if (pjob == NULL)
+        {
+        pjob = find_job(jobidstr);
+        }
+
+      if (pjob != NULL)
+        {
+        int bad;
+
+        svrattrl tA;
+        
+        /* job exists, so get the attributes and update them */
+
+        attr_name = strtok(NULL, "=");
+        
+        while (attr_name != NULL)
+          {
+          attr_value = strtok(NULL, ",");
+          
+          if (LOGLEVEL >= 9)
+            {
+            sprintf(log_buffer, "Mom sent changed attribute %s value %s for job %s",
+              attr_name,
+              attr_value,
+              pjob->ji_qs.ji_jobid);
+              
+            log_event(
+              PBSEVENT_JOB,
+              PBS_EVENTCLASS_JOB,
+              pjob->ji_qs.ji_jobid,
+              log_buffer);  
+            }
+          
+          memset(&tA, 0, sizeof(tA));
+
+          tA.al_name  = attr_name;
+          tA.al_resc  = "";
+          tA.al_value = attr_value;
+          tA.al_op    = SET;
+
+          modify_job_attr(
+            pjob,
+            &tA,                              /* I: ATTR_sched_hint - svrattrl */
+            ATR_DFLAG_MGWR | ATR_DFLAG_SvWR,
+            &bad);
+
+          attr_name = strtok(NULL, "=");
+          }
+        }
+      else if (pjob == NULL)
+        {
+        /* job is reported by mom but server has no record of job */
+
+        sprintf(log_buffer, "stray job %s reported on %s",
+                jobidstr,
+                np->nd_name);
+
+        log_err(-1, id, log_buffer);
+
+        }
+      }
+    }
+
+  free(jobdata);
+  }  /* END update_job_data() */
+
+
+
+
 
 /*
  * send_cluster_addrs - sends IS_CLUSTER_ADDRS messages to a set of nodes
@@ -1241,7 +1161,6 @@ int is_stat_get(
 
   while (((ret_info = disrst(stream, &rc)) != NULL) && (rc == DIS_SUCCESS))
     {
-
     /* add the info to the "temp" attribute */
 
     if (decode_arst(&temp, NULL, NULL, ret_info))
@@ -1291,6 +1210,13 @@ int is_stat_get(
         msg_error = 1;
         }
       }
+    else if (server.sv_attr[(int)SRV_ATR_MomJobSync].at_val.at_long &&
+             !strncmp(ret_info, "jobdata=", 8))
+      {
+      /* update job attributes based on what the MOM gives us */
+      
+      update_job_data(np, ret_info + strlen("jobdata="));
+      }
     else if (server.sv_attr[(int)SRV_ATR_MomJobSync].at_val.at_long &&
              !strncmp(ret_info, "jobs=", 5))
       {
@@ -1318,7 +1244,25 @@ int is_stat_get(
           }
         }
       }
+    else if(server.sv_attr[(int)SRV_ATR_NPDefault].at_val.at_long)
+      {
+        struct pbsnode *pnode;
+        int i;
+        long max_np;
+        long nsnfreediff;
 
+        max_np = server.sv_attr[(int)SRV_ATR_NPDefault].at_val.at_long;
+
+        for(i = 0; i < svr_totnodes; i++)
+          {
+          pnode = pbsndlist[i];
+
+          nsnfreediff = pnode->nd_nsn - pnode->nd_nsnfree;
+          pnode->nd_nsn = max_np;
+          pnode->nd_nsnfree = max_np - nsnfreediff;
+
+          }
+      }
     free(ret_info);
     }    /* END while (rc != DIS_EOD) */
 
@@ -1701,13 +1645,10 @@ int add_cluster_addrs(
 
       if (LOGLEVEL >= 8)
         {
-        sprintf(log_buffer, "adding node[%d] interface[%d] %ld.%ld.%ld.%ld to hello response",
+        sprintf(log_buffer, "adding node[%d] interface[%d] %s to hello response",
                 i,
                 j,
-                (ipaddr & 0xff000000) >> 24,
-                (ipaddr & 0x00ff0000) >> 16,
-                (ipaddr & 0x0000ff00) >> 8,
-                (ipaddr & 0x000000ff));
+                netaddr_pbs_net_t(ipaddr));
 
         log_event(PBSEVENT_ADMIN, PBS_EVENTCLASS_SERVER, id, log_buffer);
         }
@@ -1817,9 +1758,9 @@ const char *PBSServerCmds2[] =
   };
 
 /*
-** Input is coming from another server (MOM) over a DIS rpp stream.
-** Read the stream to get a Inter-Server request.
-*/
+ * Input is coming from the pbs_mom over a DIS rpp stream.
+ * Read the stream to get a Inter-Server request.
+ */
 
 void is_request(
 
@@ -2010,6 +1951,7 @@ found:
         log_event(PBSEVENT_ADMIN, PBS_EVENTCLASS_SERVER, id, log_buffer);
         }
 
+#ifndef ALT_CLSTR_ADDR
       ret = is_compose(stream, IS_CLUSTER_ADDRS);
 
       if (ret != DIS_SUCCESS)
@@ -2036,7 +1978,7 @@ found:
       /* rpp_eom(stream); */
 
       /* CLUSTER_ADDRS successful */
-
+#endif
       node->nd_state &= ~(INUSE_NEEDS_HELLO_PING);
 
       break;
@@ -2198,11 +2140,13 @@ write_node_state(void)
   int   savemask;
 
   if (LOGLEVEL >= 5)
+    {
     DBPRT(("write_node_state: entered\n"))
+    }
 
-    /* don't store volatile states like down and unknown */
+  /* don't store volatile states like down and unknown */
 
-    savemask = INUSE_OFFLINE | INUSE_RESERVE;
+  savemask = INUSE_OFFLINE | INUSE_RESERVE;
 
   if (nstatef != NULL)
     {
@@ -3065,7 +3009,7 @@ static char *mod_spec(
 
   *cp++ = ':';
 
-  strcpy(cp,global);
+  strcpy(cp, global);
 
   return(line);
   }  /* END mod_spec() */
@@ -3199,9 +3143,9 @@ int MSNPrintF(
     return(FAILURE);
     }
 
-  va_start(Args, Format);
+  va_start(Args,Format);
 
-  len = vsnprintf(*BPtr, *BSpace, Format, Args);
+  len = vsnprintf(*BPtr,*BSpace,Format,Args);
 
   va_end(Args);
 
@@ -3209,9 +3153,23 @@ int MSNPrintF(
     {
     return(FAILURE);
     }
+  
+  if (len >= *BSpace)
+    {
+    /* truncation occurred due to attempted
+     * overflow! */
 
+    /* do not place BPtr past the end of the buffer:
+     * it is too dangerous (calling function could derference it
+     * to check for empty string, etc.)! */
+
+    *BPtr += (*BSpace) - 1;
+    *BSpace = 0;
+
+    return(FAILURE);
+    }
+  
   *BPtr += len;
-
   *BSpace -= len;
 
   return(SUCCESS);
@@ -3236,6 +3194,7 @@ static int node_spec(
   char  *spec,       /* I */
   int    early,      /* I (boolean) */
   int    exactmatch, /* I (boolean) - NOT USED */
+  char  *ProcBMStr,  /* I */
   char  *FailNode,   /* O (optional,minsize=1024) */
   char  *EMsg)       /* O (optional,minsize=1024) */
 
@@ -3300,7 +3259,7 @@ static int node_spec(
     return(-1);
     }
 
-  if ((globs = strchr(spec,'#')) != NULL)
+  if ((globs = strchr(spec, '#')) != NULL)
     {
     *globs++ = '\0';
 
@@ -3365,7 +3324,7 @@ static int node_spec(
 
     if (EMsg != NULL)
       {
-      strncpy(EMsg,log_buffer,1024);
+      strncpy(EMsg, log_buffer, 1024);
       }
 
     return(-1);
@@ -3375,7 +3334,7 @@ static int node_spec(
     {
     sprintf(log_buffer, "job allocation debug: %d requested, %d svr_clnodes, %d svr_totnodes",
       num,
-      svr_clnodes, 
+      svr_clnodes,
       svr_totnodes);
 
     log_record(
@@ -3412,6 +3371,18 @@ static int node_spec(
     if (pnode->nd_state & INUSE_DELETED)
       continue;
 
+#ifdef GEOMETRY_REQUESTS
+    /* must be dedicated node use for cpusets */
+    if (IS_VALID_STR(ProcBMStr)) 
+      {
+      if (pnode->nd_state != INUSE_FREE)
+        continue;
+
+      if (node_satisfies_request(pnode,ProcBMStr) == FALSE)
+        continue;
+      }
+#endif /* GEOMETRY_REQUESTS */
+
     if (LOGLEVEL >= 6)
       {
       DBPRT(("%s: %s nsn %d, nsnfree %d, nsnshared %d\n",
@@ -3739,6 +3710,302 @@ static int node_spec(
 
 
 
+#ifdef GEOMETRY_REQUESTS
+/**
+ * get_bitmap
+ *
+ * @param pjob (I) - the job whose bitmap is be retrieved
+ * @param ProcBMPtr (O) - the ptr to the string where the bitmap will be stored
+ * @param ProcBMSize (I) - the size of the string ProcBMPtr points to
+ * @return FAILURE if there is no specified bitmap or either pjob or ProcBMStrPtr are NULL
+ * @return SUCCESS otherwise
+ */
+int get_bitmap(
+
+  job  *pjob,        /* I */
+  int   ProcBMSize,  /* I */
+  char *ProcBMPtr)   /* O */
+
+  {
+  resource     *presc;
+  resource_def *prd;
+
+  char          LocalBM[MAX_BM];
+
+  if ((pjob == NULL) ||
+      (ProcBMPtr == NULL))
+    {
+    return(FAILURE);
+    }
+
+  LocalBM[0] = '\0';
+
+  /* read the bitmap from the resource list */
+  prd = find_resc_def(svr_resc_def,"procs_bitmap",svr_resc_size);
+  presc = find_resc_entry(&pjob->ji_wattr[(int)JOB_ATR_resource],prd);
+  
+  if ((presc != NULL) && 
+      (presc->rs_value.at_flags & ATR_VFLAG_SET))
+    {
+    snprintf(LocalBM,sizeof(LocalBM),"%s",presc->rs_value.at_val.at_str);
+    }
+  else
+    {
+    /* fail if there was no bitmap given */
+
+    return(FAILURE);
+    }
+
+  if (LocalBM[0] == '\0')
+    {
+    /* fail if there was no bitmap given */
+
+    return(FAILURE);
+    }
+  else
+    {
+    snprintf(ProcBMPtr,sizeof(LocalBM),"%s",LocalBM);
+    return(SUCCESS);
+    }
+  } /* end get_bitmap() */
+
+
+
+
+/**
+ * node_satisfies_request
+ *
+ * @param pnode (I) - the node to check for validity
+ * @param ProcBMStr (I) - the bitmap of procs requested
+ * @return TRUE - if the node satisfies the bitmap, FALSE otherwise
+ * @return BM_ERROR if the bitmap isn't valid
+ */
+int node_satisfies_request(
+
+  struct pbsnode *pnode,     /* I */
+  char           *ProcBMStr) /* I */
+
+  {
+  int BMLen;
+  int BMIndex;
+
+  struct pbssubn *snp; 
+
+  if (IS_VALID_STR(ProcBMStr) == FALSE)
+    return(BM_ERROR);
+
+  /* nodes are exclusive when we're using bitmaps */
+  if (pnode->nd_state != INUSE_FREE)
+    return(FALSE);
+
+  BMLen = strlen(ProcBMStr);
+
+  /* process in reverse because ProcBMStr[0] referes to core index 0 */
+  BMIndex = BMLen-1;
+
+  /* check if the requested processors are available on this node */
+  for (snp = pnode->nd_psn;snp && BMIndex >= 0;snp = snp->next)
+    {
+    /* don't check cores that aren't requested */
+    if (ProcBMStr[BMIndex--] != '1')
+      continue;
+
+    /* cannot use this node, one of the requested cores is busy */
+    if (snp->inuse != INUSE_FREE)
+      return(FALSE);
+    }
+
+  if (BMIndex >= 0)
+    {
+    /* this means we didn't finish checking the string -
+     * the node doesn't have enough processors */
+
+    return(FALSE);
+    }
+
+  /* passed all checks, we're good */
+  return(TRUE);
+  } /* END node_satisfies_request() */
+
+
+
+
+/**
+ * reserve_node
+ *
+ * @param pnode - node to reserve
+ * @param pjob - the job to be added to the node
+ * @param hlistptr - a pointer to the host list 
+ */
+
+int reserve_node(
+
+  struct pbsnode  *pnode,     /* I/O */
+  short            newstate,  /* I */
+  job             *pjob,      /* I */
+  char            *ProcBMStr, /* I */
+  struct howl    **hlistptr)  /* O */
+
+  {
+  int BMLen;
+  int BMIndex;
+
+  struct pbssubn *snp; 
+
+  if ((pnode == NULL) ||
+      (pjob == NULL) ||
+      (hlistptr == NULL))
+    {
+    return(FAILURE);
+    }
+
+  BMLen = strlen(ProcBMStr);
+  BMIndex = BMLen-1;
+
+  /* now reserve each node */
+  for (snp = pnode->nd_psn;snp && BMIndex >= 0;snp = snp->next)
+    {
+    /* ignore unrequested cores */
+    if (ProcBMStr[BMIndex--] != '1')
+      continue;
+
+    add_job_to_node(pnode,snp,INUSE_JOB,pjob,exclusive);
+
+    build_host_list(hlistptr,snp,pnode);
+    }
+  
+  /* mark the node as exclusive */
+  pnode->nd_state = INUSE_JOB;
+
+  return(SUCCESS);
+  }
+#endif /* GEOMETRY_REQUESTS */
+
+
+
+
+/**
+ * adds this job to the node's list of jobs
+ * checks to be sure not to add duplicates
+ *
+ * conditionally updates the subnode's state
+ * decrements the amount of needed nodes
+ *
+ * @param pnode - the node that the job is running on
+ * @param nd_psn - the subnode (processor) that the job is running on
+ * @param newstate - the state nodes are transitioning to when used
+ * @param pjob - the job that is going to be run
+ * @param exclusive - TRUE if jobs are given exclusive node use, FALSE otherwise
+ */
+int add_job_to_node(
+
+  struct pbsnode *pnode,     /* I/O */
+  struct pbssubn *snp,       /* I/O */
+  short           newstate,  /* I */
+  job            *pjob,      /* I */
+  int             exclusive) /* I */
+
+  {
+  char *id = "add_job_to_node";
+  struct jobinfo *jp;
+
+  /* NOTE:  search existing job array.  add job only if job not already in place */
+  if (LOGLEVEL >= 5)
+    {
+    sprintf(log_buffer, "allocated node %s/%d to job %s (nsnfree=%d)",
+      pnode->nd_name,
+      snp->index,
+      pjob->ji_qs.ji_jobid,
+      pnode->nd_nsnfree);
+
+    log_record(
+      PBSEVENT_SCHED,
+      PBS_EVENTCLASS_REQUEST,
+      id,
+      log_buffer);
+    DBPRT(("%s\n", log_buffer));
+    }
+
+  for (jp = snp->jobs;jp != NULL;jp = jp->next)
+    {
+    if (jp->job == pjob)
+      break;
+    }
+
+  if (jp == NULL)
+    {
+    /* add job to front of subnode job array */
+
+    jp = (struct jobinfo *)malloc(sizeof(struct jobinfo));
+    jp->next = snp->jobs;
+    snp->jobs = jp;
+    jp->job = pjob;
+    pnode->nd_nsnfree--;            /* reduce free count */
+
+    /* if no free VPs, set node state */
+    if (pnode->nd_nsnfree <= 0)     
+      pnode->nd_state = newstate;
+
+    if (snp->inuse == INUSE_FREE)
+      {
+      snp->inuse = newstate;
+
+      if (!exclusive)
+        pnode->nd_nsnshared++;
+      }
+    }
+
+  /* decrement the amount of nodes needed */
+  --pnode->nd_needed;
+
+  return(SUCCESS);
+  }
+
+
+
+/**
+ * builds the host list (hlist)
+ *
+ * @param pnode - the node being added to the host list
+ * @param hlist - the host list being built
+ */ 
+int build_host_list(
+
+  struct howl    **hlistptr,  /* O */
+  struct pbssubn  *snp,       /* I */
+  struct pbsnode  *pnode)     /* I */
+  
+  {
+  struct howl *curr;
+  struct howl *prev;
+  struct howl *hp;
+
+  /* initialize the pointers */
+  curr = (struct howl *)malloc(sizeof(struct howl));
+  curr->order = pnode->nd_order;
+  curr->name  = pnode->nd_name;
+  curr->index = snp->index;
+
+  /* find the proper place in the list */
+  for (prev = NULL, hp = *hlistptr;hp;prev = hp, hp = hp->next)
+    {
+    if (curr->order <= hp->order)
+      break;
+    }  /* END for (prev) */
+
+  /* set the correct pointers in the list */
+  curr->next = hp;
+
+  if (prev == NULL)
+    *hlistptr = curr;
+  else
+    prev->next = curr;
+
+  return(SUCCESS);
+  }
+
+
+
 
 /*
  * set_nodes() - Call node_spec() to allocate nodes then set them inuse.
@@ -3756,14 +4023,9 @@ int set_nodes(
 
   {
 
-  struct howl
-    {
-    char *name;
-    int   order;
-    int   index;
-
-    struct howl *next;
-    } *hp, *hlist, *curr, *prev, *nxt;
+  struct howl *hp;
+  struct howl *hlist;
+  struct howl *nxt;
 
   int     i;
   short   newstate;
@@ -3777,6 +4039,8 @@ int set_nodes(
   struct pbssubn *snp;
   char           *nodelist;
 
+  char   ProcBMStr[MAX_BM];
+
   if (FailHost != NULL)
     FailHost[0] = '\0';
 
@@ -3796,9 +4060,14 @@ int set_nodes(
       log_buffer);
     }
 
+  ProcBMStr[0] = '\0';
+#ifdef GEOMETRY_REQUESTS
+  get_bitmap(pjob,sizeof(ProcBMStr),ProcBMStr);
+#endif /* GEOMETRY_REQUESTS */
+
   /* allocate nodes */
 
-  if ((i = node_spec(spec, 1, 1, FailHost, EMsg)) == 0) /* check spec */
+  if ((i = node_spec(spec, 1, 1, ProcBMStr, FailHost, EMsg)) == 0) /* check spec */
     {
     /* no resources located, request failed */
 
@@ -3836,7 +4105,6 @@ int set_nodes(
 
   for (i = 0;i < svr_totnodes;i++)
     {
-    struct jobinfo *jp;
 
     pnode = pbsndlist[i];
 
@@ -3853,6 +4121,18 @@ int set_nodes(
       }
 
     /* within the node, check each subnode */
+#ifdef GEOMETRY_REQUESTS
+    if (ProcBMStr[0] != '\0')
+      {
+      /* check node here, a request was given */
+      if (node_satisfies_request(pnode,ProcBMStr) == TRUE)
+        {
+        reserve_node(pnode,newstate,pjob,ProcBMStr,&hlist);
+        }
+
+      continue;
+      }
+#endif /* GEOMETRY_REQUESTS */
 
     for (snp = pnode->nd_psn;snp && pnode->nd_needed;snp = snp->next)
       {
@@ -3869,114 +4149,11 @@ int set_nodes(
 
       /* Mark subnode as being IN USE */
 
-      if (LOGLEVEL >= 5)
-        {
-        sprintf(log_buffer, "allocated node %s/%d to job %s (nsnfree=%d)",
-          pnode->nd_name,
-          snp->index,
-          pjob->ji_qs.ji_jobid,
-          pnode->nd_nsnfree);
-
-        log_record(
-          PBSEVENT_SCHED,
-          PBS_EVENTCLASS_REQUEST,
-          id,
-          log_buffer);
-
-        DBPRT(("%s\n", log_buffer));
-        }
-
-      /* NOTE:  search existing job array.  add job only if job not already in place */
-
-      for (jp = snp->jobs;jp != NULL;jp = jp->next)
-        {
-        if (jp->job == pjob)
-          break;
-        }
-
-      if (jp == NULL)
-        {
-        /* add job to front of subnode job array */
-
-        jp = (struct jobinfo *)malloc(sizeof(struct jobinfo));
-
-        if (jp == NULL)
-          {
-          sprintf(log_buffer,"cannot alloc memory");
-
-          log_record(
-            PBSEVENT_SCHED,
-            PBS_EVENTCLASS_REQUEST,
-            id,
-            log_buffer);
-
-          if (EMsg != NULL)
-            sprintf(EMsg,"cannot alloc memory");
-
-          return(PBSE_RESCUNAV);
-          }
-
-        jp->next = snp->jobs;
-
-        snp->jobs = jp;
-
-        jp->job = pjob;
-
-        pnode->nd_nsnfree--;            /* reduce free count */
-
-        if (snp->inuse == INUSE_FREE)
-          {
-          snp->inuse = newstate;
-
-          if (!exclusive)
-            pnode->nd_nsnshared++;
-          }
-        }
-
-      /* build list of nodes ordered to match request */
-
-      curr = (struct howl *)malloc(sizeof(struct howl));
-
-      if (curr == NULL)
-        {
-        sprintf(log_buffer,"cannot alloc memory");
-
-        log_record(
-          PBSEVENT_SCHED,
-          PBS_EVENTCLASS_REQUEST,
-          id,
-          log_buffer);
-
-        if (EMsg != NULL)
-          sprintf(EMsg,"cannot alloc memory");
-
-        return(PBSE_RESCUNAV);
-        }
-
-      curr->order = pnode->nd_order;
-
-      curr->name  = pnode->nd_name;
-
-      curr->index = snp->index;
-
-      for (prev = NULL, hp = hlist;hp;prev = hp, hp = hp->next)
-        {
-        if (curr->order <= hp->order)
-          break;
-        }  /* END for (prev) */
-
-      curr->next = hp;
-
-      if (prev == NULL)
-        hlist = curr;
-      else
-        prev->next = curr;
-
-      --pnode->nd_needed;
+      add_job_to_node(pnode,snp,newstate,pjob,exclusive);
+  
+      build_host_list(&hlist,snp,pnode);
       }  /* END for (snp) */
 
-    if (pnode->nd_nsnfree <= 0)     /* if no free VPs, set node state */
-      pnode->nd_state = newstate;
     }    /* END for (i) */
 
   if (hlist == NULL)
@@ -3994,7 +4171,7 @@ int set_nodes(
       }
 
     if (EMsg != NULL)
-      sprintf(EMsg,"no nodes can be allocated to job");
+      sprintf(EMsg, "no nodes can be allocated to job");
 
     return(PBSE_RESCUNAV);
     }  /* END if (hlist == NULL) */
@@ -4098,7 +4275,7 @@ int node_avail_complex(
 
   holdnum = svr_numnodes;
 
-  ret = node_spec(spec, 1, 0, NULL, NULL);
+  ret = node_spec(spec, 1, 0, NULL, NULL, NULL);
 
   svr_numnodes = holdnum;
 
@@ -4286,7 +4463,7 @@ int node_reserve(
     return(-1);
     }
 
-  if ((ret_val = node_spec(nspec, 0, 0, NULL, NULL)) >= 0)
+  if ((ret_val = node_spec(nspec, 0, 0, NULL, NULL, NULL)) >= 0)
     {
     /*
     ** Zero or more of the needed Nodes are available to be
@@ -4554,7 +4731,7 @@ static void set_one_old(
   struct jobinfo *jp;
   char        *pc;
 
-  if ((pc = strchr(name,(int)'/')))
+  if ((pc = strchr(name, (int)'/')))
     {
     index = atoi(pc + 1);
 
@@ -4569,7 +4746,7 @@ static void set_one_old(
     {
     pnode = pbsndmast[i];
 
-    if (!strcmp(name,pnode->nd_name))
+    if (strcmp(name, pnode->nd_name) == 0)
       {
       /* Mark node as being IN USE ...  */
 
@@ -4653,14 +4830,14 @@ void set_old_nodes(
       return;
       }
 
-    while ((po = strrchr(old,(int)'+')) != NULL)
+    while ((po = strrchr(old, (int)'+')) != NULL)
       {
       *po++ = '\0';
 
-      set_one_old(po,pjob,shared);
+      set_one_old(po, pjob, shared);
       }
 
-    set_one_old(old,pjob,shared);
+    set_one_old(old, pjob, shared);
 
     free(old);
     }  /* END if ((pbsndmast != NULL) && ...) */
