@@ -280,7 +280,13 @@ void req_register(
     }
   else
     {
-    strcpy(preq->rq_ind.rq_register.rq_svr, preq->rq_host);
+    /* We ignore what qsub sent us for the host. We need to use the 
+     * server_name so we know we can connect to the active server.
+     * This is an high availability consideration */
+    if(server_name != NULL)
+      strcpy(preq->rq_ind.rq_register.rq_svr, server_name);
+    else
+      strcpy(preq->rq_ind.rq_register.rq_svr, preq->rq_host);
     }
 
   /* Register a dependency */
@@ -382,7 +388,10 @@ void req_register(
                 {
                 /* has prior register, update it */
 
-                strcpy(pdj->dc_svr, preq->rq_ind.rq_register.rq_svr);
+                if(server_name != NULL)
+                  strncpy(pdj->dc_svr, server_name, PBS_MAXSERVERNAME);
+                else
+                  strncpy(pdj->dc_svr, preq->rq_ind.rq_register.rq_svr, PBS_MAXSERVERNAME);
                 }
               }
             else if ((rc = register_dep(pattr, preq, type, &made)) == 0)
@@ -604,9 +613,6 @@ void req_register(
   }  /* END req_register() */
 
 
-
-
-
 /*
  * post_doq (que not dog) - post request/reply processing for depend_on_que
  * i.e. the sending of register operations.
@@ -1427,7 +1433,10 @@ static int register_sync(
     {
     /* existing regist., just update the location of the child */
 
-    strcpy(pdj->dc_svr, host);
+    if(server_name != NULL)
+      strcpy(pdj->dc_svr, server_name);
+    else
+      strcpy(pdj->dc_svr, host);
 
     return(0);
     }
@@ -1492,7 +1501,10 @@ static int register_dep(
 
   if ((pdj = find_dependjob(pdep, preq->rq_ind.rq_register.rq_child)))
     {
-    strcpy(pdj->dc_svr, preq->rq_ind.rq_register.rq_svr);
+    if(server_name != NULL)
+      strcpy(pdj->dc_svr, server_name);
+    else
+      strcpy(pdj->dc_svr, preq->rq_ind.rq_register.rq_svr);
 
     *made = 0;
 
@@ -1648,7 +1660,10 @@ static struct depend_job *make_dependjob(
     pdj->dc_cost  = 0;
 
     strcpy(pdj->dc_child, jobid);
-    strcpy(pdj->dc_svr, host);
+    if(server_name != NULL)
+      strcpy(pdj->dc_svr, server_name);
+    else
+      strcpy(pdj->dc_svr, host);
 
     append_link(&pdep->dp_jobs, &pdj->dc_link, pdj);
     }
@@ -2480,7 +2495,10 @@ static int build_depend(
 
           if (pwhere)
             {
-            (void)strcpy(pdjb->dc_svr, pwhere + 1);
+            if(server_name != NULL)
+              (void)strcpy(pdjb->dc_svr, server_name);
+            else
+              (void)strcpy(pdjb->dc_svr, pwhere + 1);
             }
           else
             {
