@@ -1088,8 +1088,20 @@ attribute_def svr_attr_def[] =
       PARENT_TYPE_SERVER
   },
 
+  /* SRV_ATR_JobForceCancelTime */
+  {   ATTR_jobforcecanceltime,     /* job_force_cancel_time */
+      decode_l,
+      encode_l,
+      set_l,
+      comp_l,
+      free_null,
+      NULL_FUNC,
+      MGR_ONLY_SET,
+      ATR_TYPE_LONG,
+      PARENT_TYPE_SERVER
+  },
+
   /* site supplied server attribute definitions if any, see site_svr_attr_*.h  */
 #include "site_svr_attr_def.h"
 
-
   };
