@@ -1,45 +1,45 @@
 /*
 *         OpenPBS (Portable Batch System) v2.3 Software License
-* 
+*
 * Copyright (c) 1999-2000 Veridian Information Solutions, Inc.
 * All rights reserved.
-* 
+*
 * ---------------------------------------------------------------------------
 * For a license to use or redistribute the OpenPBS software under conditions
 * other than those described below, or to purchase support for this software,
 * please contact Veridian Systems, PBS Products Department ("Licensor") at:
-* 
+*
 *    www.OpenPBS.org  +1 650 967-4675                  sales@OpenPBS.org
 *                        877 902-4PBS (US toll-free)
 * ---------------------------------------------------------------------------
-* 
+*
 * This license covers use of the OpenPBS v2.3 software (the "Software") at
 * your site or location, and, for certain users, redistribution of the
 * Software to other sites and locations.  Use and redistribution of
 * OpenPBS v2.3 in source and binary forms, with or without modification,
 * are permitted provided that all of the following conditions are met.
 * After December 31, 2001, only conditions 3-6 must be met:
-* 
+*
 * 1. Commercial and/or non-commercial use of the Software is permitted
 *    provided a current software registration is on file at www.OpenPBS.org.
 *    If use of this software contributes to a publication, product, or
 *    service, proper attribution must be given; see www.OpenPBS.org/credit.html
-* 
+*
 * 2. Redistribution in any form is only permitted for non-commercial,
 *    non-profit purposes.  There can be no charge for the Software or any
 *    software incorporating the Software.  Further, there can be no
 *    expectation of revenue generated as a consequence of redistributing
 *    the Software.
-* 
+*
 * 3. Any Redistribution of source code must retain the above copyright notice
 *    and the acknowledgment contained in paragraph 6, this list of conditions
 *    and the disclaimer contained in paragraph 7.
-* 
+*
 * 4. Any Redistribution in binary form must reproduce the above copyright
 *    notice and the acknowledgment contained in paragraph 6, this list of
 *    conditions and the disclaimer contained in paragraph 7 in the
 *    documentation and/or other materials provided with the distribution.
-* 
+*
 * 5. Redistributions in any form must be accompanied by information on how to
 *    obtain complete source code for the OpenPBS software and any
 *    modifications and/or additions to the OpenPBS software.  The source code
@@ -47,23 +47,23 @@
 *    than the cost of distribution plus a nominal fee, and all modifications
 *    and additions to the Software must be freely redistributable by any party
 *    (including Licensor) without restriction.
-* 
+*
 * 6. All advertising materials mentioning features or use of the Software must
 *    display the following acknowledgment:
-* 
+*
 *     "This product includes software developed by NASA Ames Research Center,
-*     Lawrence Livermore National Laboratory, and Veridian Information 
+*     Lawrence Livermore National Laboratory, and Veridian Information
 *     Solutions, Inc.
 *     Visit www.OpenPBS.org for OpenPBS software support,
 *     products, and information."
-* 
+*
 * 7. DISCLAIMER OF WARRANTY
-* 
+*
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND. ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND NON-INFRINGEMENT
 * ARE EXPRESSLY DISCLAIMED.
-* 
+*
 * IN NO EVENT SHALL VERIDIAN CORPORATION, ITS AFFILIATED COMPANIES, OR THE
 * U.S. GOVERNMENT OR ANY OF ITS AGENCIES BE LIABLE FOR ANY DIRECT OR INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
@@ -72,7 +72,7 @@
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-* 
+*
 * This license will be governed by the laws of the Commonwealth of Virginia,
 * without reference to its choice of law rules.
 */
@@ -91,57 +91,68 @@
 
 /*
 struct tracking {
-        time_t   tk_mtime;  
+        time_t   tk_mtime;
         int      tk_hopcount;
         char     tk_jobid[PBS_MAXSVRJOBID+1];
         char     tk_location[PBS_MAXDEST+1];
         char     tk_state;
-};
+  };
 */
 
 void
 prt_track_struct(struct tracking *ptrack)
-{
-        if (ptrack->tk_jobid[0] == '\0')
-          return;
+  {
+  if (ptrack->tk_jobid[0] == '\0')
+    return;
 
-	printf("---------------------------------------------------\n");
-	printf("jobid:\t%s\n", ptrack->tk_jobid);
-	printf("mtime:\t\t%lu\n", (unsigned long int)ptrack->tk_mtime);
-	printf("hopcount:\t%d\n", ptrack->tk_hopcount);
-	printf("location:\t%s\n", ptrack->tk_location);
-	printf("state:\t\t%c\n", ptrack->tk_state);
-}
+  printf("---------------------------------------------------\n");
+
+  printf("jobid:\t%s\n", ptrack->tk_jobid);
+
+  printf("mtime:\t\t%lu\n", (unsigned long int)ptrack->tk_mtime);
+
+  printf("hopcount:\t%d\n", ptrack->tk_hopcount);
+
+  printf("location:\t%s\n", ptrack->tk_location);
+
+  printf("state:\t\t%c\n", ptrack->tk_state);
+  }
 
 
-int main(argc, argv)
-	int argc;
-	char *argv[];
-{
-	int amt;
-	int f;
-	int fp;
-        struct tracking track;
+int
+main(int argc, char *argv[])
+  {
+  int amt;
+  int f;
+  int fp;
 
-	if (argc < 1) {
-		fprintf(stderr, "usage: %s file [file ...]\n", argv[0]);
-		return 1;
-	}
+  struct tracking track;
 
-	for (f=1; f<argc; ++f) {
-		fp = open(argv[f], O_RDONLY, 0);
-		if (fp < 0) {
-			perror("open failed");
-			fprintf(stderr, "unable to open file %s\n", argv[f]);
-			exit(1);
-		}
-		while ((amt = read(fp, &track, sizeof(track))) == sizeof(track))
-                  {
-		  prt_track_struct(&track);
-                  }
+  if (argc < 1)
+    {
+    fprintf(stderr, "usage: %s file [file ...]\n", argv[0]);
+    return 1;
+    }
 
-		(void)close(fp);
-		printf("\n");
-	}
-	return (0);
-}
+  for (f = 1; f < argc; ++f)
+    {
+    fp = open(argv[f], O_RDONLY, 0);
+
+    if (fp < 0)
+      {
+      perror("open failed");
+      fprintf(stderr, "unable to open file %s\n", argv[f]);
+      exit(1);
+      }
+
+    while ((amt = read(fp, &track, sizeof(track))) == sizeof(track))
+      {
+      prt_track_struct(&track);
+      }
+
+    (void)close(fp);
+    printf("\n");
+    }
+
+  return (0);
+  }
